@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2009-2022, Intel Corporation
+* Copyright (c) 2009-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -51,6 +51,9 @@ class XRenderHal_Platform_Interface;
 #define MHW_RENDERHAL_ASSERTMESSAGE(_message, ...)                                        \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_CM, MOS_CM_SUBCOMP_RENDERHAL, _message, ##__VA_ARGS__)
 
+#define MHW_RENDERHAL_WARNINGMESSAGE(_message, ...)                                       \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CM, MOS_CM_SUBCOMP_RENDERHAL, _message, ##__VA_ARGS__)
+
 #define MHW_RENDERHAL_NORMALMESSAGE(_message, ...)                                        \
     MOS_NORMALMESSAGE(MOS_COMPONENT_CM, MOS_CM_SUBCOMP_RENDERHAL, _message, ##__VA_ARGS__)
 
@@ -109,7 +112,7 @@ class XRenderHal_Platform_Interface;
 
 #define RENDERHAL_SSH_BINDING_TABLES        1
 #define RENDERHAL_SSH_BINDING_TABLES_MIN    1
-#define RENDERHAL_SSH_BINDING_TABLES_MAX   16
+#define RENDERHAL_SSH_BINDING_TABLES_MAX   32
 #define RENDERHAL_SSH_BINDING_TABLE_ALIGN  64
 
 #define RENDERHAL_SSH_SURFACE_STATES       40
@@ -1006,6 +1009,13 @@ typedef struct _RENDERHAL_INTERFACE_DESCRIPTOR_PARAMS
 //! \brief  ======== HW Abstraction Params ===================================
 //!
 
+struct RENDERHAL_STATE_LOCATION
+{
+    PMOS_RESOURCE stateHeap = 0;
+    uint32_t      offset    = 0;
+};
+using PRENDERHAL_STATE_LOCATION = RENDERHAL_STATE_LOCATION*;
+
 typedef struct _RENDERHAL_SURFACE_STATE_PARAMS
 {
     RENDERHAL_SURFACE_STATE_TYPE    Type                      : 5;              // Type of surface state
@@ -1034,6 +1044,7 @@ typedef struct _RENDERHAL_SURFACE_STATE_PARAMS
     uint32_t                        surfaceType               : 11;
     MOS_COMPONENT                   Component                 : 4;
     uint32_t                        combineChannelY           : 1;              // Combine 2 Luma Channel pixels into 1 pixel, so that kernel can reduce write times
+    uint32_t                        usePackedPlanar           : 1;              // Force using packed planr
     RENDERHAL_MEMORY_OBJECT_CONTROL MemObjCtl;                                  // Caching attributes
 } RENDERHAL_SURFACE_STATE_PARAMS, *PRENDERHAL_SURFACE_STATE_PARAMS;
 
@@ -1068,7 +1079,7 @@ typedef struct _RENDERHAL_SURFACE_STATE_ENTRY
     uint16_t                        wUYOffset;                                      //
     uint16_t                        wVXOffset;                                      // (X,Y) offset V (AVS/ADI)
     uint16_t                        wVYOffset;                                      //
-    uint64_t                        stateGfxAddress;                                // Gfx Address of Surface State
+    RENDERHAL_STATE_LOCATION        stateLocation;                                  // Gfx Location of Surface State
 } RENDERHAL_SURFACE_STATE_ENTRY, *PRENDERHAL_SURFACE_STATE_ENTRY;
 
 //!
@@ -1144,6 +1155,7 @@ typedef struct _RENDERHAL_ENLARGE_PARAMS
     int32_t iKernelCount;     // Number of Kernels that can be loaded
     int32_t iKernelHeapSize;  // Size of GSH block for kernels
     int32_t iCurbeSize;       // Size of CURBE area
+    int32_t iMediaIDs;        // Number of Media Interface Descriptors
 } RENDERHAL_ENLARGE_PARAMS, *PRENDERHAL_ENLARGE_PARAMS;
 
 //!
@@ -1189,6 +1201,7 @@ typedef struct _RENDERHAL_INTERFACE
     MHW_WALKER_MODE              MediaWalkerMode;                               // Media object walker mode from Regkey: repel, dual mode, quad mode
     uint32_t                     euThreadSchedulingMode;
     uint32_t                     largeGrfMode;
+    uint32_t                     enableVariableRegisterSizeAllocationVrt;
 
     RENDERHAL_SURFACE_STATE_TYPE SurfaceTypeDefault;                            // Surface State type default
     RENDERHAL_SURFACE_STATE_TYPE SurfaceTypeAdvanced;                           // Surface State type advanced
@@ -1208,6 +1221,7 @@ typedef struct _RENDERHAL_INTERFACE
     bool                        bComputeContextInUse;                           // Compute Context use for media
     bool                        isBindlessHeapInUse;                            // Bindless Heap Mode use
 
+    uint32_t                    grfSize;                                        // The size of GRF registers, which can be get from GRF Registers from Spec
     uint32_t                    dwMaskCrsThdConDataRdLn;                        // Unifies pfnSetupInterfaceDescriptor for g75,g8,...
     uint32_t                    dwMinNumberThreadsInGroup;                      // Unifies pfnSetupInterfaceDescriptor for g75,g8,...
     uint32_t                    dwCurbeBlockAlign;                              // Unifies pfnLoadCurbeData - Curbe Block Alignment
@@ -1327,6 +1341,10 @@ typedef struct _RENDERHAL_INTERFACE
     MOS_STATUS (* pfnRefreshSync) (
                 PRENDERHAL_INTERFACE     pRenderHal);
 
+    MOS_STATUS (*pfnOverwriteEnlargedHeapParams)(
+        PRENDERHAL_INTERFACE      pRenderHal,
+        RENDERHAL_ENLARGE_PARAMS &params);
+
     //---------------------------
     // SSH, surface states
     //---------------------------
@@ -1483,12 +1501,12 @@ typedef struct _RENDERHAL_INTERFACE
                 PMHW_SAMPLER_STATE_PARAM    pSamplerParams,
                 int32_t                     iSamplers);
 
-    MOS_STATUS (*pfnSetAndGetSamplerStates) (
-                PRENDERHAL_INTERFACE     pRenderHal,
-                int32_t                  iMediaID,
-                PMHW_SAMPLER_STATE_PARAM pSamplerParams,
-                int32_t                  iSamplers,
-                std::map<uint32_t, uint64_t> &samplerMap);
+    MOS_STATUS (*pfnSetAndGetSamplerStates)(
+        PRENDERHAL_INTERFACE                          pRenderHal,
+        int32_t                                       iMediaID,
+        PMHW_SAMPLER_STATE_PARAM                      pSamplerParams,
+        int32_t                                       iSamplers,
+        std::map<uint32_t, RENDERHAL_STATE_LOCATION> &samplerMap);
 
     int32_t (* pfnAllocateMediaID) (
                 PRENDERHAL_INTERFACE        pRenderHal,
