@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2011-2021, Intel Corporation
+* Copyright (c) 2011-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -62,6 +62,9 @@
 #define CODECHAL_HW_ASSERTMESSAGE(_message, ...)                                        \
     MOS_ASSERTMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_HW, _message, ##__VA_ARGS__)
 
+#define CODECHAL_HW_WARNINGMESSAGE(_message, ...)                                       \
+    MOS_WARNINGMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_HW, _message, ##__VA_ARGS__)
+
 #define CODECHAL_HW_NORMALMESSAGE(_message, ...)                                        \
     MOS_NORMALMESSAGE(MOS_COMPONENT_CODEC, MOS_CODEC_SUBCOMP_HW, _message, ##__VA_ARGS__)
 
@@ -332,6 +335,12 @@ public:
         MhwInterfaces     *mhwInterfaces,
         bool              disableScalability = false);
 
+    static CodechalHwInterface *Create(
+        PMOS_INTERFACE    osInterface,
+        CODECHAL_FUNCTION codecFunction,
+        MhwInterfaces     *mhwInterfaces,
+        bool              disableScalability);
+
     //!
     //! \brief    Get avp interface
     //! \details  Get avp interface in codechal hw interface next
@@ -472,7 +481,7 @@ public:
     {
         CODECHAL_HW_FUNCTION_ENTER;
 
-        if (MEDIA_IS_WA(m_waTable, WaHucStreamoutEnable))
+        if (MEDIA_IS_WA(m_waTable, WaHucStreamoutEnable) && m_osInterface)
         {
             m_osInterface->pfnFreeResource(
                 m_osInterface,
@@ -485,10 +494,13 @@ public:
                 &m_dummyStreamOut);
         }
 
-        m_osInterface->pfnFreeResource(m_osInterface, &m_conditionalBbEndDummy);
+        if (m_osInterface)
+        {
+            m_osInterface->pfnFreeResource(m_osInterface, &m_conditionalBbEndDummy);
 
-        Delete_MhwCpInterface(m_cpInterface); 
-        m_cpInterface = nullptr;
+            m_osInterface->pfnDeleteMhwCpInterface(m_cpInterface);
+            m_cpInterface = nullptr;
+        }
 
         if (m_miInterface)
         {
@@ -1236,7 +1248,7 @@ public:
     //! \return   MOS_STATUS
     //!           MOS_STATUS_SUCCESS if success, else fail reason
     //!
-    MOS_STATUS AddHucDummyStreamOut(
+    virtual MOS_STATUS AddHucDummyStreamOut(
         PMOS_COMMAND_BUFFER cmdBuffer);
 
     //!
