@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2015-2017, Intel Corporation
+* Copyright (c) 2015-2020, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -138,6 +138,7 @@ VAStatus DdiDecodeHEVC::ParseSliceParams(
         }
         codecSlcParams++;
     }
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -313,6 +314,20 @@ VAStatus DdiDecodeHEVC::ParsePicParams(
     codecPicParams->RefBottomFieldFlag         = 0;
     codecPicParams->StatusReportFeedbackNumber = 0;
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    // Picture Info
+    DECODE_EVENTDATA_INFO_PICTUREVA eventData = {0};
+    uint32_t minCtbSize        = 1 << (codecPicParams->log2_min_luma_coding_block_size_minus3 + 3);
+    eventData.CodecFormat                   = m_ddiDecodeCtx->wMode;
+    eventData.FrameType                     = codecPicParams->IntraPicFlag == 1 ? I_TYPE : MIXED_TYPE;
+    eventData.PicStruct                     = FRAME_PICTURE;
+    eventData.Width                         = codecPicParams->PicWidthInMinCbsY * minCtbSize;
+    eventData.Height                        = codecPicParams->PicHeightInMinCbsY * minCtbSize;
+    eventData.Bitdepth                      = codecPicParams->bit_depth_luma_minus8 + 8;
+    eventData.ChromaFormat                  = codecPicParams->chroma_format_idc;  // 0-4:0:0; 1-4:2:0; 2-4:2:2; 3-4:4:4
+    MOS_TraceEvent(EVENT_DECODE_INFO_PICTUREVA, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -402,6 +417,7 @@ VAStatus DdiDecodeHEVC::RenderPicture(
 
             DdiMedia_MediaBufferToMosResource(m_ddiDecodeCtx->BufMgr.pBitStreamBuffObject[index], &m_ddiDecodeCtx->BufMgr.resBitstreamBuffer);
             m_ddiDecodeCtx->DecodeParams.m_dataSize += dataSize;
+
             break;
         }
         case VASliceParameterBufferType:
@@ -423,6 +439,7 @@ VAStatus DdiDecodeHEVC::RenderPicture(
         {
             VAIQMatrixBufferHEVC *imxBuf = (VAIQMatrixBufferHEVC *)data;
             DDI_CHK_RET(ParseIQMatrix(mediaCtx, imxBuf),"ParseIQMatrix failed!");
+
             break;
         }
         case VAPictureParameterBufferType:
@@ -442,6 +459,7 @@ VAStatus DdiDecodeHEVC::RenderPicture(
             }
 
             MOS_SecureMemcpy(m_ddiDecodeCtx->DecodeParams.m_subsetParams, dataSize, data, dataSize);
+
             break;
         }
         case VAProcPipelineParameterBufferType:
@@ -538,13 +556,21 @@ VAStatus DdiDecodeHEVC::SetDecodeParams()
     if (m_decProcessingType == VA_DEC_PROCESSING)
     {
         auto procParams =
-            (PCODECHAL_DECODE_PROCESSING_PARAMS)m_ddiDecodeCtx->DecodeParams.m_procParams;
-        procParams->pInputSurface = (&m_ddiDecodeCtx->DecodeParams)->m_destSurface;
+            (DecodeProcessingParams *)m_ddiDecodeCtx->DecodeParams.m_procParams;
+        procParams->m_inputSurface = (&m_ddiDecodeCtx->DecodeParams)->m_destSurface;
         // codechal_decode_sfc.c expects Input Width/Height information.
-        procParams->pInputSurface->dwWidth    = procParams->pInputSurface->OsResource.iWidth;
-        procParams->pInputSurface->dwHeight = procParams->pInputSurface->OsResource.iHeight;
-        procParams->pInputSurface->dwPitch    = procParams->pInputSurface->OsResource.iPitch;
-        procParams->pInputSurface->Format    = procParams->pInputSurface->OsResource.Format;
+        procParams->m_inputSurface->dwWidth  = procParams->m_inputSurface->OsResource.iWidth;
+        procParams->m_inputSurface->dwHeight = procParams->m_inputSurface->OsResource.iHeight;
+        procParams->m_inputSurface->dwPitch  = procParams->m_inputSurface->OsResource.iPitch;
+        procParams->m_inputSurface->Format   = procParams->m_inputSurface->OsResource.Format;
+
+        if(m_requireInputRegion)
+        {
+            procParams->m_inputSurfaceRegion.m_x = 0;
+            procParams->m_inputSurfaceRegion.m_y = 0;
+            procParams->m_inputSurfaceRegion.m_width = procParams->m_inputSurface->dwWidth;
+            procParams->m_inputSurfaceRegion.m_height = procParams->m_inputSurface->dwHeight;
+        }
     }
 #endif
      return VA_STATUS_SUCCESS;
@@ -838,11 +864,11 @@ VAStatus DdiDecodeHEVC::CodecHalInit(
 #ifdef _DECODE_PROCESSING_SUPPORTED
     if (m_decProcessingType == VA_DEC_PROCESSING)
     {
-        PCODECHAL_DECODE_PROCESSING_PARAMS procParams = nullptr;
+        DecodeProcessingParams *procParams = nullptr;
         
         m_codechalSettings->downsamplingHinted = true;
         
-        procParams = (PCODECHAL_DECODE_PROCESSING_PARAMS)MOS_AllocAndZeroMemory(sizeof(CODECHAL_DECODE_PROCESSING_PARAMS));
+        procParams = (DecodeProcessingParams *)MOS_AllocAndZeroMemory(sizeof(DecodeProcessingParams));
         if (procParams == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
@@ -850,8 +876,8 @@ VAStatus DdiDecodeHEVC::CodecHalInit(
         }
         
         m_ddiDecodeCtx->DecodeParams.m_procParams = procParams;
-        procParams->pOutputSurface = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
-        if (procParams->pOutputSurface == nullptr)
+        procParams->m_outputSurface = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
+        if (procParams->m_outputSurface == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
             goto CleanUpandReturn;
@@ -897,8 +923,8 @@ CleanUpandReturn:
     if (m_ddiDecodeCtx->DecodeParams.m_procParams)
     {
         auto procParams =
-            (PCODECHAL_DECODE_PROCESSING_PARAMS)m_ddiDecodeCtx->DecodeParams.m_procParams;
-        MOS_FreeMemory(procParams->pOutputSurface);
+            (DecodeProcessingParams *)m_ddiDecodeCtx->DecodeParams.m_procParams;
+        MOS_FreeMemory(procParams->m_outputSurface);
         
         MOS_FreeMemory(m_ddiDecodeCtx->DecodeParams.m_procParams);
         m_ddiDecodeCtx->DecodeParams.m_procParams = nullptr;
