@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2015-2018, Intel Corporation
+* Copyright (c) 2015-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -89,6 +89,11 @@ VAStatus DdiDecodeHEVCG12::ParseSliceParams(
         }
         else
         {
+            if (m_decodeErrorFlag)
+            {
+                /* If error occurs in current GOP (m_decodeErrorFlag is true), set slice_temporal_mvp_enabled_flag = 0 to avoid GPU hang */
+                codecSlcParams->LongSliceFlags.fields.slice_temporal_mvp_enabled_flag = 0;
+            }
             codecSlcParams->slice_data_size   = slc->slice_data_size;
             codecSlcParams->slice_data_offset = sliceBaseOffset + slc->slice_data_offset;
             if (slcBase->slice_data_flag)
@@ -199,6 +204,7 @@ VAStatus DdiDecodeHEVCG12::ParseSliceParams(
         }
         codecSlcParams++;
     }
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -349,6 +355,12 @@ VAStatus DdiDecodeHEVCG12::ParsePicParams(
     codecPicParams->num_tile_columns_minus1 = picParamBase->num_tile_columns_minus1;
     codecPicParams->num_tile_rows_minus1    = picParamBase->num_tile_rows_minus1;
 
+    if (codecPicParams->IdrPicFlag)
+    {
+        /* Initiate m_decodeErrorFlag to false when it's an IDR picture */
+        m_decodeErrorFlag = false;
+    }
+
     for (i = 0; i < HEVC_NUM_MAX_TILE_COLUMN - 1; i++)
     {
         codecPicParams->column_width_minus1[i] = picParamBase->column_width_minus1[i];
@@ -430,6 +442,20 @@ VAStatus DdiDecodeHEVCG12::ParsePicParams(
         MOS_SecureMemcpy(&codecPicParamsScc->PredictorPaletteEntries, uiCopySize, &picParamScc->predictor_palette_entries, uiCopySize);
     }
 
+#if MOS_EVENT_TRACE_DUMP_SUPPORTED
+    // Picture Info
+    DECODE_EVENTDATA_INFO_PICTUREVA eventData = {0};
+    uint32_t minCtbSize        = 1 << (codecPicParams->log2_min_luma_coding_block_size_minus3 + 3);
+    eventData.CodecFormat                   = m_ddiDecodeCtx->wMode;
+    eventData.FrameType                     = codecPicParams->IntraPicFlag == 1 ? I_TYPE : MIXED_TYPE;
+    eventData.PicStruct                     = FRAME_PICTURE;
+    eventData.Width                         = codecPicParams->PicWidthInMinCbsY * minCtbSize;
+    eventData.Height                        = codecPicParams->PicHeightInMinCbsY * minCtbSize;
+    eventData.Bitdepth                      = codecPicParams->bit_depth_luma_minus8 + 8;
+    eventData.ChromaFormat                  = codecPicParams->chroma_format_idc;  // 0-4:0:0; 1-4:2:0; 2-4:2:2; 3-4:4:4
+    MOS_TraceEvent(EVENT_DECODE_INFO_PICTUREVA, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
+#endif
+
     return VA_STATUS_SUCCESS;
 }
 
@@ -495,7 +521,11 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
                 {
                     Format = Format_Y210;
                 }
+#if VA_CHECK_VERSION(1, 9, 0)
+                else if(rtTbl->pCurrentRT->format == Media_Format_Y216 || rtTbl->pCurrentRT->format == Media_Format_Y212)
+#else
                 else if(rtTbl->pCurrentRT->format == Media_Format_Y216)
+#endif
                 {
                     Format = Format_Y216;
                 }
@@ -507,7 +537,11 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
                 {
                     Format = Format_Y410;
                 }
+#if VA_CHECK_VERSION(1, 9, 0)
+                else if(rtTbl->pCurrentRT->format == Media_Format_Y416 || rtTbl->pCurrentRT->format == Media_Format_Y412)
+#else
                 else if(rtTbl->pCurrentRT->format == Media_Format_Y416)
+#endif
                 {
                     Format = Format_Y416;
                 }
@@ -529,7 +563,11 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
             else if (picParams->chroma_format_idc == 2)           //422
             {
                 Format = Format_Y210;
+#if VA_CHECK_VERSION(1, 9, 0)
+                if(rtTbl->pCurrentRT->format == Media_Format_Y216 || rtTbl->pCurrentRT->format == Media_Format_Y212)
+#else
                 if(rtTbl->pCurrentRT->format == Media_Format_Y216)
+#endif
                 {
                     Format = Format_Y216;
                 }
@@ -537,7 +575,11 @@ MOS_FORMAT DdiDecodeHEVCG12::GetFormat()
             else                                                  //444
             {
                 Format = Format_Y410;
+#if VA_CHECK_VERSION(1, 9, 0)
+                if(rtTbl->pCurrentRT->format == Media_Format_Y416 || rtTbl->pCurrentRT->format == Media_Format_Y412)
+#else
                 if(rtTbl->pCurrentRT->format == Media_Format_Y416)
+#endif
                 {
                     Format = Format_Y416;
                 }
@@ -815,10 +857,16 @@ VAStatus DdiDecodeHEVCG12::AllocSliceControlBuffer(
     bufMgr     = &(m_ddiDecodeCtx->BufMgr);
     availSize = m_sliceCtrlBufNum - bufMgr->dwNumSliceControl;
 
+    if(buf->uiNumElements < 1 || buf->iSize < 1)
+        return VA_STATUS_ERROR_ALLOCATION_FAILED;
+
     if(m_ddiDecodeCtx->bShortFormatInUse)
     {
         if(availSize < buf->uiNumElements)
         {
+            if (buf->iSize / buf->uiNumElements != sizeof(VASliceParameterBufferBase))
+                return VA_STATUS_ERROR_ALLOCATION_FAILED;
+
             newSize   = sizeof(VASliceParameterBufferBase) * (m_sliceCtrlBufNum - availSize + buf->uiNumElements);
             bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufBaseHEVC = (VASliceParameterBufferBase *)realloc(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufBaseHEVC, newSize);
             if(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufBaseHEVC == nullptr)
@@ -837,6 +885,9 @@ VAStatus DdiDecodeHEVCG12::AllocSliceControlBuffer(
         {
             if(availSize < buf->uiNumElements)
             {
+                if (buf->iSize / buf->uiNumElements != sizeof(VASliceParameterBufferHEVC))
+                    return VA_STATUS_ERROR_ALLOCATION_FAILED;
+
                 newSize   = sizeof(VASliceParameterBufferHEVC) * (m_sliceCtrlBufNum - availSize + buf->uiNumElements);
                 bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVC = (VASliceParameterBufferHEVC *)realloc(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVC, newSize);
                 if(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVC == nullptr)
@@ -853,6 +904,9 @@ VAStatus DdiDecodeHEVCG12::AllocSliceControlBuffer(
         {
             if(availSize < buf->uiNumElements)
             {
+                if (buf->iSize / buf->uiNumElements != sizeof(VASliceParameterBufferHEVCExtension))
+                    return VA_STATUS_ERROR_ALLOCATION_FAILED;
+
                 newSize   = sizeof(VASliceParameterBufferHEVCExtension) * (m_sliceCtrlBufNum - availSize + buf->uiNumElements);
                 bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVCRext= (VASliceParameterBufferHEVCExtension*)realloc(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVCRext, newSize);
                 if(bufMgr->Codec_Param.Codec_Param_HEVC.pVASliceParaBufHEVCRext== nullptr)
@@ -977,11 +1031,11 @@ VAStatus DdiDecodeHEVCG12::CodecHalInit(
 #ifdef _DECODE_PROCESSING_SUPPORTED
     if (m_decProcessingType == VA_DEC_PROCESSING)
     {
-        PCODECHAL_DECODE_PROCESSING_PARAMS procParams = nullptr;
+        DecodeProcessingParams *procParams = nullptr;
         
         m_codechalSettings->downsamplingHinted = true;
         
-        procParams = (PCODECHAL_DECODE_PROCESSING_PARAMS)MOS_AllocAndZeroMemory(sizeof(CODECHAL_DECODE_PROCESSING_PARAMS));
+        procParams = (DecodeProcessingParams *)MOS_AllocAndZeroMemory(sizeof(DecodeProcessingParams));
         if (procParams == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
@@ -989,8 +1043,8 @@ VAStatus DdiDecodeHEVCG12::CodecHalInit(
         }
         
         m_ddiDecodeCtx->DecodeParams.m_procParams = procParams;
-        procParams->pOutputSurface = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
-        if (procParams->pOutputSurface == nullptr)
+        procParams->m_outputSurface = (PMOS_SURFACE)MOS_AllocAndZeroMemory(sizeof(MOS_SURFACE));
+        if (procParams->m_outputSurface == nullptr)
         {
             vaStatus = VA_STATUS_ERROR_ALLOCATION_FAILED;
             goto CleanUpandReturn;
@@ -1038,8 +1092,8 @@ CleanUpandReturn:
     if (m_ddiDecodeCtx->DecodeParams.m_procParams)
     {
         auto procParams =
-            (PCODECHAL_DECODE_PROCESSING_PARAMS)m_ddiDecodeCtx->DecodeParams.m_procParams;
-        MOS_FreeMemory(procParams->pOutputSurface);
+            (DecodeProcessingParams *)m_ddiDecodeCtx->DecodeParams.m_procParams;
+        MOS_FreeMemory(procParams->m_outputSurface);
         
         MOS_FreeMemory(m_ddiDecodeCtx->DecodeParams.m_procParams);
         m_ddiDecodeCtx->DecodeParams.m_procParams = nullptr;
@@ -1078,4 +1132,4 @@ bool DdiDecodeHEVCG12::IsSccProfile()
 extern template class MediaDdiFactory<DdiMediaDecode, DDI_DECODE_CONFIG_ATTR>;
 
 static bool hevcRegistered =
-    MediaDdiFactory<DdiMediaDecode, DDI_DECODE_CONFIG_ATTR>::RegisterCodec<DdiDecodeHEVCG12>(DECODE_ID_HEVC_G12);
+    MediaDdiFactory<DdiMediaDecode, DDI_DECODE_CONFIG_ATTR>::RegisterCodec<DdiDecodeHEVCG12>(DECODE_ID_HEVC_REXT);
