@@ -90,9 +90,11 @@ MOS_STATUS VPFeatureManagerXe_Xpm_Base::CheckFeatures(void * params, bool &bApgF
         return MOS_STATUS_SUCCESS;
     }
 
-    if (disableVeboxOutput && disableSfc)
+    // If bForceToRender is set as true, then output pipe is decided by whether HDR is enabled.
+    // If HDR is enabled, use APO path. Otherwise legacy path is selected.
+    if (disableVeboxOutput && disableSfc && !pvpParams->bForceToRender)
     {
-        VP_PUBLIC_NORMALMESSAGE("Fallback to legacy since both vebox output and sfc being disabled.");
+        VP_PUBLIC_NORMALMESSAGE("Fallback to legacy since 1. both vebox output and sfc being disabled. 2. Render is not forced to");
         return MOS_STATUS_SUCCESS;
     }
 
@@ -127,14 +129,7 @@ MOS_STATUS VPFeatureManagerXe_Xpm_Base::CheckFeatures(void * params, bool &bApgF
     // WA: Force NV12 16K to render
     if (pvpParams->pTarget[0]->Format == Format_NV12 && pvpParams->pTarget[0]->dwHeight > VPHAL_RNDR_16K_HEIGHT_LIMIT)
     {
-        VPHAL_RENDER_NORMALMESSAGE("Disable VEBOX/SFC for NV12 16k resolution");
-        return MOS_STATUS_SUCCESS;
-    }
-
-    bool isHdrNeeded = IsHdrNeeded(pvpParams->pSrc[0], pvpParams->pTarget[0]);
-    if (isHdrNeeded && IsCroppingNeeded(pvpParams->pSrc[0]))
-    {
-        VP_PUBLIC_NORMALMESSAGE("Disable APO Path for HDR Cropping");
+        VP_RENDER_NORMALMESSAGE("Disable VEBOX/SFC for NV12 16k resolution");
         return MOS_STATUS_SUCCESS;
     }
 
@@ -178,6 +173,8 @@ MOS_STATUS VPFeatureManagerXe_Xpm_Base::CheckFeatures(void * params, bool &bApgF
     if (!IsVeboxOutFeasible(pvpParams) &&
         !IsSfcOutputFeasible(pvpParams))
     {
+        bool isHdrNeeded = IsHdrNeeded(pvpParams->pSrc[0], pvpParams->pTarget[0]);
+
         if (!isHdrNeeded)
         {
             return MOS_STATUS_SUCCESS;
@@ -203,6 +200,14 @@ MOS_STATUS VPFeatureManagerXe_Xpm_Base::CheckFeatures(void * params, bool &bApgF
         {
             VP_PUBLIC_NORMALMESSAGE("If HVS case, still go to APG path, not need change to Composition");
         }
+        else if (IsHdrNeeded(pvpParams->pSrc[0], pvpParams->pTarget[0]))
+        {
+            VP_PUBLIC_NORMALMESSAGE("If HDR case, still go to APG path, not need change to Composition");
+        }
+        else if (IS_COLOR_SPACE_BT2020_YUV(pvpParams->pSrc[0]->ColorSpace) && IS_COLOR_SPACE_BT2020_YUV(pvpParams->pTarget[0]->ColorSpace))
+        {
+            VP_PUBLIC_NORMALMESSAGE("If input color space is BT2020 and output color space is BT2020_FullRange, go to APG path.");
+        }
         else
         {
             VP_PUBLIC_NORMALMESSAGE("DDI choose to use Composition, change to Composition.");
@@ -261,7 +266,7 @@ bool VPFeatureManagerXe_Xpm_Base::IsOutputFormatSupported(
     }
     else
     {
-        VPHAL_RENDER_NORMALMESSAGE("Unsupported Render Target Format '0x%08x' for SFC Pipe.", outSurface->Format);
+        VP_RENDER_NORMALMESSAGE("Unsupported Render Target Format '0x%08x' for SFC Pipe.", outSurface->Format);
         ret = false;
     }
 
