@@ -161,7 +161,6 @@ namespace decode
         DecodePipeline *         m_pipeline       = nullptr;
         MediaFeatureManager *    m_featureManager = nullptr;
         DecodeAllocator *        m_allocator      = nullptr;
-        PMOS_INTERFACE           m_osInterface    = nullptr;
         CodechalHwInterface *    m_hwInterface    = nullptr;
         MhwVdboxHucInterface *   m_hucInterface   = nullptr;
         MhwVdboxVdencInterface * m_vdencInterface = nullptr;
@@ -171,7 +170,7 @@ namespace decode
         static const uint32_t m_hucStatusInvalidMask = 0;         //!< Invalid mask of Huc status MMIO
         uint32_t       m_hucStatusMask = m_hucStatusInvalidMask;  //!< MMIO mask for HuC status
         uint32_t       m_hucStatus2Mask = m_hucStatusInvalidMask; //!< MMIO mask for HuC status2
-    MEDIA_CLASS_DEFINE_END(DecodeHucBasic_G12_Base)
+    MEDIA_CLASS_DEFINE_END(decode__DecodeHucBasic_G12_Base)
     };
 }
 #endif  // !__DECODE_HUC_G12_Base_H__
