@@ -27,9 +27,6 @@
 #define __ENCODE_AV1_BASIC_FEATURE_XE_LPM_PLUS_BASE_H__
 
 #include "encode_av1_basic_feature.h"
-#if _MEDIA_RESERVED
-#include "codec_def_encode_av1_ext.h"
-#endif
 
 namespace encode
 {
@@ -42,8 +39,7 @@ public:
                      TrackedBuffer                      *trackedBuf,
                      RecycleResource                    *recycleBuf,
                      void                               *constSettings) :
-                     Av1BasicFeature(allocator, hwInterface, trackedBuf, recycleBuf, constSettings),
-                     m_featureManager(featureManager){};
+                     Av1BasicFeature(allocator, hwInterface, trackedBuf, recycleBuf, constSettings){ m_featureManager = featureManager;};
 
     virtual ~Av1BasicFeatureXe_Lpm_Plus_Base(){};
 
@@ -53,9 +49,6 @@ public:
 
     MHW_SETPAR_DECL_HDR(AVP_PIC_STATE);
 
-protected:
-    MediaFeatureManager *m_featureManager = nullptr;
-
 MEDIA_CLASS_DEFINE_END(encode__Av1BasicFeatureXe_Lpm_Plus_Base)
 };
 
