@@ -19,16 +19,18 @@
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
+
 #include "MDF_FC_common_genx.h"
 
-_GENX_MAIN_ void Y210_444DScale16_Buf_3_Rot_180(
+_GENX_MAIN_ void Y410_444DScale16_Buf_3_Rot_180(
     CURBE_INPUT_OUTPUT,
     GLOBAL_BUFFER_INPUT_OUTPUT)
 {
-
+#define Y410_SUPPORT
 #define BUFFER_3
 #define ROTATE_180
-#include "Y210_DScale_Buf.h"
+#include "PA_DScale_Buf.h"
 #undef ROTATE_180
 #undef BUFFER_3
+#undef Y410_SUPPORT
 }
\ No newline at end of file
