@@ -19,16 +19,18 @@
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
+
 #include "MDF_FC_common_genx.h"
 
-_GENX_MAIN_ void Y210_444Scale16_Buf_4_Rot_90(
+_GENX_MAIN_ void Y410_444Scale16_Buf_4_Rot_90(
     CURBE_INPUT_OUTPUT,
     GLOBAL_BUFFER_INPUT_OUTPUT)
 {
-
+#define Y410_SUPPORT
 #define BUFFER_4
 #define ROTATE_90
-#include "Y210_Scale_Buf.h"
+#include "PA_Scale_Buf.h"
 #undef ROTATE_90
 #undef BUFFER_4
+#undef Y410_SUPPORT
 }
\ No newline at end of file
