@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2018-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -28,7 +28,14 @@
 
 #include "decode_allocator.h"
 #include "decode_utils.h"
+#include "External/Common/GmmResourceInfoExt.h"
+#include "External/Common/GmmCachePolicyExt.h"
+#include "decode_utils.h"
+#include "media_allocator.h"
+#include "mos_os_cp_interface_specific.h"
+#include "mos_utilities.h"
 #include "decode_resource_array.h"
+#include "mos_interface.h"
 
 namespace decode {
 
@@ -37,8 +44,7 @@ DecodeAllocator::DecodeAllocator(PMOS_INTERFACE osInterface, bool limitedLMemBar
 {
     m_allocator = MOS_New(Allocator, m_osInterface);
 #if (_DEBUG || _RELEASE_INTERNAL)
-    m_forceLockable = ReadUserFeature(
-        __MEDIA_USER_FEATURE_VALUE_FORCE_DECODE_RESOURCE_LOCKABLE_ID, m_osInterface->pOsContext).u32Data;
+    m_forceLockable = ReadUserFeature(m_osInterface->pfnGetUserSettingInstance(m_osInterface), "ForceDecodeResourceLockable", MediaUserSetting::Group::Sequence).Get<uint32_t>();
 #endif
 }
 
@@ -97,7 +103,9 @@ BufferArray * DecodeAllocator::AllocateBufferArray(
     bool initOnAllocate, uint8_t initValue, bool bPersistent)
 {
     if (!m_allocator)
+    {
         return nullptr;
+    }
 
     BufferArray * bufferArray = MOS_New(BufferArray, this);
     if (bufferArray == nullptr)
@@ -122,7 +130,9 @@ MOS_SURFACE* DecodeAllocator::AllocateSurface(
     MOS_TILE_MODE_GMM gmmTileMode)
 {
     if (!m_allocator)
+    {
         return nullptr;
+    }
 
     MOS_ALLOC_GFXRES_PARAMS allocParams;
     MOS_ZeroMemory(&allocParams, sizeof(MOS_ALLOC_GFXRES_PARAMS));
@@ -151,6 +161,44 @@ MOS_SURFACE* DecodeAllocator::AllocateSurface(
     return surface;
 }
 
+MOS_SURFACE *DecodeAllocator::AllocateLinearSurface(
+    const uint32_t width, const uint32_t height, const char *nameOfSurface,
+    MOS_FORMAT format, bool isCompressible,
+    ResourceUsage resUsageType, ResourceAccessReq accessReq,
+    MOS_TILE_MODE_GMM gmmTileMode)
+{
+    if (!m_allocator)
+    {
+        return nullptr;
+    }
+
+    MOS_ALLOC_GFXRES_PARAMS allocParams;
+    MOS_ZeroMemory(&allocParams, sizeof(MOS_ALLOC_GFXRES_PARAMS));
+    allocParams.Type              = MOS_GFXRES_2D;
+    allocParams.TileType          = MOS_TILE_LINEAR;
+    allocParams.Format            = format;
+    allocParams.dwWidth           = width;
+    allocParams.dwHeight          = height;
+    allocParams.dwArraySize       = 1;
+    allocParams.pBufName          = nameOfSurface;
+    allocParams.bIsCompressible   = isCompressible;
+    allocParams.ResUsageType      = static_cast<MOS_HW_RESOURCE_DEF>(resUsageType);
+    allocParams.m_tileModeByForce = gmmTileMode;
+    SetAccessRequirement(accessReq, allocParams);
+
+    MOS_SURFACE *surface = m_allocator->AllocateSurface(allocParams, false, COMPONENT_Decode);
+    if (surface == nullptr)
+    {
+        return nullptr;
+    }
+    if (GetSurfaceInfo(surface) != MOS_STATUS_SUCCESS)
+    {
+        DECODE_ASSERTMESSAGE("Failed to get surface informaton for %s", nameOfSurface);
+    }
+
+    return surface;
+}
+
 SurfaceArray * DecodeAllocator::AllocateSurfaceArray(
     const uint32_t width, const uint32_t height, const char* nameOfSurface,
     const uint32_t numberOfSurface, MOS_FORMAT format, bool isCompressed,
@@ -182,11 +230,25 @@ PMHW_BATCH_BUFFER DecodeAllocator::AllocateBatchBuffer(
     bool notLockable = false;
     bool inSystemMem = false;
 
-    // Config setting if running with limited LMem bar config.
-    if (m_limitedLMemBar)
+    // Config setting if running with limited LMem bar config or HM enabled.
+    if (m_limitedLMemBar || 
+        (m_osInterface->osCpInterface != nullptr && m_osInterface->osCpInterface->IsHMEnabled())
+    )
     {
-        notLockable = (accessReq == notLockableVideoMem);
-        inSystemMem = (accessReq == lockableSystemMem);
+        if (accessReq == notLockableVideoMem)
+        {
+            if (m_osInterface->osCpInterface != nullptr && m_osInterface->osCpInterface->IsHMEnabled())
+            {
+                notLockable = true;
+                inSystemMem = false;
+            }
+        }
+        else
+        {
+            // allocate batch buffer in systemMem with limited LMem bar config due to local memory limitation
+            notLockable = false;
+            inSystemMem = true;
+        }
     }
 
 #if (_DEBUG || _RELEASE_INTERNAL)
@@ -435,7 +497,12 @@ MOS_STATUS DecodeAllocator::Destroy(MOS_SURFACE& surface)
 
     MOS_SURFACE* dup = MOS_New(MOS_SURFACE);
     DECODE_CHK_NULL(dup);
-    DECODE_CHK_STATUS(MOS_SecureMemcpy(dup, sizeof(MOS_SURFACE), &surface, sizeof(MOS_SURFACE)));
+    MOS_STATUS status = MOS_SecureMemcpy(dup, sizeof(MOS_SURFACE), &surface, sizeof(MOS_SURFACE));
+    if (status != MOS_STATUS_SUCCESS)
+    {
+        MOS_Delete(dup);
+        return status;
+    }
 
     //if free the compressed surface, need set the sync dealloc flag as 1 for sync dealloc for aux table update
     MOS_GFXRES_FREE_FLAGS resFreeFlags = {0};
@@ -583,48 +650,23 @@ MOS_STATUS DecodeAllocator::RegisterResource(PMOS_RESOURCE osResource)
 
 ResourceUsage DecodeAllocator::ConvertGmmResourceUsage(const GMM_RESOURCE_USAGE_TYPE gmmResUsage)
 {
-    ResourceUsage resUsageType;
-    switch (gmmResUsage)
+    if (nullptr == m_osInterface)
     {
-    case GMM_RESOURCE_USAGE_DECODE_INPUT_BITSTREAM:
-        resUsageType = resourceInputBitstream;
-        break;
-    case GMM_RESOURCE_USAGE_DECODE_INPUT_REFERENCE:
-        resUsageType = resourceInputReference;
-        break;
-    case GMM_RESOURCE_USAGE_DECODE_INTERNAL_READ:
-        resUsageType = resourceInternalRead;
-        break;
-    case GMM_RESOURCE_USAGE_DECODE_INTERNAL_WRITE:
-        resUsageType = resourceInternalWrite;
-        break;
-    case GMM_RESOURCE_USAGE_DECODE_INTERNAL_READ_WRITE_CACHE:
-        resUsageType = resourceInternalReadWriteCache;
-        break;
-    case GMM_RESOURCE_USAGE_DECODE_INTERNAL_READ_WRITE_NOCACHE:
-        resUsageType = resourceInternalReadWriteNoCache;
-        break;
-    case GMM_RESOURCE_USAGE_DECODE_OUTPUT_PICTURE:
-        resUsageType = resourceOutputPicture;
-        break;
-    case GMM_RESOURCE_USAGE_DECODE_OUTPUT_STATISTICS_WRITE:
-        resUsageType = resourceStatisticsWrite;
-        break;
-    case GMM_RESOURCE_USAGE_DECODE_OUTPUT_STATISTICS_READ_WRITE:
-        resUsageType = resourceStatisticsReadWrite;
-        break;
-    default:
-        resUsageType = resourceDefault;
+        DECODE_ASSERTMESSAGE("mos interface is nullptr")
+        return resourceDefault;
     }
-    return resUsageType;
+    MOS_HW_RESOURCE_DEF gmmUsage = m_osInterface->pfnGmmToMosResourceUsageType(gmmResUsage);
+    return (ResourceUsage)gmmUsage;
 }
 
 void DecodeAllocator::SetAccessRequirement(
     ResourceAccessReq accessReq, MOS_ALLOC_GFXRES_PARAMS &allocParams)
 {
     // The default setting is lockableVideoMem, just use default setting
-    // if not running with limited LMem bar config.
-    if (!m_limitedLMemBar)
+    // if not running with limited LMem bar config and not enabled HM. otherwise goto required setting.
+    if (!m_limitedLMemBar && 
+        !(m_osInterface->osCpInterface != nullptr && m_osInterface->osCpInterface->IsHMEnabled())
+    )
     {
         allocParams.Flags.bNotLockable = 0;
         allocParams.dwMemType = MOS_MEMPOOL_VIDEOMEMORY;
