@@ -35,6 +35,9 @@
 #include "mhw_vdbox_avp_itf.h"
 #include "mhw_vdbox_huc_itf.h"
 #include "encode_mem_compression.h"
+#if _MEDIA_RESERVED
+#include "codec_def_encode_av1_ext.h"
+#endif
 
 namespace encode
 {
@@ -85,7 +88,9 @@ public:
 
     virtual MOS_STATUS GetTrackedBuffers() override;
 
-    Av1StreamIn *GetStreamIn();
+    virtual Av1StreamIn *GetStreamIn();
+
+    virtual MediaFeatureManager *GetFeatureManager();
 
     MOS_STATUS GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP_STATE& mmcState, uint32_t& compressionFormat) const;
 
@@ -158,8 +163,12 @@ public:
     bool                               m_enableSWBackAnnotation = true;                        //!< indicate whether SW back annotation enabled or not
     bool                               m_enableSWStitching = false;                             //!< indicate whether SW bitstream stitching enabled or not
     bool                               m_enableNonDefaultMapping = false;                       //!< indicate whether Non-default mapping enabled or not
-    bool                               m_adaptiveRounding   = false;                            //!< whether adaptive rounding will be enabled
+
+    RoundingMethod                     m_roundingMethod = fixedRounding;
     bool                               m_enableCDEF = false;
+    bool                               m_postCdefReconSurfaceFlag = false;
+
+    uint32_t                           m_vdencTileSliceStart[av1MaxTileNum] = { 0 };           //!< VDEnc TILE_SLICE buffer offset array for every tile
 
     enum FlushCmd
     {
