@@ -65,7 +65,9 @@ namespace encode
 
         uint16_t    UPD_MaxBRCLevel;                 // based on BGOPSize in Cmodel
         uint16_t    UPD_AdditionalHrdSizeByteCount;  // For repeated frame. App can have some header bytes not generated by HW, like skipped frame.
-        uint16_t    RSVD16[12];                      // mbz
+        uint16_t    UPD_VDEncTileSliceStateOffset;   // Group5, the 1st tile cmd start position in bytes from the begining of slbb
+        uint16_t    UPD_TileNum;
+        uint16_t    RSVD16[10];                      // mbz
 
         // BA start
         uint16_t UPD_LoopFilterParamsBitOffset;
@@ -89,7 +91,8 @@ namespace encode
         uint8_t UPD_IsFrameOBU;
         uint8_t UPD_EnableCDEFUpdate;               //flag to turn on CDEF back annotation
         uint8_t UPD_EnableLFUpdate;                 //flag to turn on LoopFilter back annotation
-        uint8_t RSVD8_1[21];
+        uint8_t UPD_PaletteOn;
+        uint8_t RSVD8_1[20];
         // BA end
 
         uint8_t     UPD_OverflowFlag;                // passed by the driver
@@ -140,8 +143,9 @@ namespace encode
         uint8_t     UPD_CQMEnabled;
         uint8_t     UPD_TempCurrentlayer;
         uint8_t     UPD_TempScalable;
+        uint8_t     UPD_AdaptiveTUEnabled;
 
-        uint8_t     RSVD8[62];
+        uint8_t     RSVD8[61];
     };
 
     typedef struct _HUC_MODE_COST
@@ -210,6 +214,7 @@ namespace encode
         virtual MOS_STATUS ConstructBatchBufferHuCBRC(PMOS_RESOURCE batchBuffer);
         MOS_STATUS         ConstructPakInsertHucBRC(PMOS_RESOURCE batchBuffer);
         virtual MOS_STATUS AddAvpPicStateBaseOnTile(MOS_COMMAND_BUFFER& cmdBuffer, SlbData &slbbData);
+        MOS_STATUS AddVdencTileSliceBaseOnTile(MOS_COMMAND_BUFFER& cmdBuffer, SlbData& slbbData);
         Av1BasicFeature *m_basicFeature = nullptr;  //!< Av1 Basic Feature used in each frame
 
         virtual MOS_STATUS SetConstDataHuCBrcUpdate();
@@ -231,7 +236,8 @@ namespace encode
         static constexpr uint32_t               m_vdboxHucAv1BrcUpdateKernelDescriptor = 19;//!< Huc AV1 Brc init kernel descriptor
 
         // Batch Buffer for VDEnc
-        MOS_RESOURCE                            m_vdencReadBatchBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][VDENC_BRC_NUM_OF_PASSES] = {};  //!< VDEnc read batch buffer
+        MOS_RESOURCE                            m_vdencReadBatchBufferOrigin[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][VDENC_BRC_NUM_OF_PASSES] = {};  //!< VDEnc read batch buffer
+        MOS_RESOURCE                            m_vdencReadBatchBufferTU7[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM][VDENC_BRC_NUM_OF_PASSES]    = {};  //!< VDEnc read batch buffer
         MOS_RESOURCE                            m_vdencPakInsertBatchBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM] = {};                      //!< VDEnc read batch buffer
         MOS_RESOURCE                            m_vdencBrcConstDataBuffer[CODECHAL_ENCODE_RECYCLED_BUFFER_NUM] = {};                        //!< VDEnc brc constant data buffer
 
