@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2018-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -221,6 +221,9 @@ MOS_STATUS HevcPipeline::DumpSeqParams(
     oss << "ScenarioInfo = " << +seqParams->ScenarioInfo << std::endl;
     oss << "Frame Size Tolerance = " << +seqParams->FrameSizeTolerance << std::endl;
     oss << "palette_mode_enabled_flag = " << +seqParams->palette_mode_enabled_flag << std::endl;
+    oss << "RGBInputStudioRange = " << +seqParams->RGBInputStudioRange << std::endl;
+    oss << "ConvertedYUVStudioRange = " << +seqParams->ConvertedYUVStudioRange << std::endl;
+    oss << "InputColorSpace = " << +seqParams->InputColorSpace << std::endl;
     oss << "Look Ahead Depth = " << +seqParams->LookaheadDepth << std::endl;
     oss << "Look Ahead Phase = " << +seqParams->bLookAheadPhase << std::endl;
 
