@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2018-2021, Intel Corporation
+* Copyright (c) 2018-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -105,6 +105,8 @@ MOS_STATUS EncodePipeline::Initialize(void *settings)
     ENCODE_CHK_STATUS_RETURN(CreateFeatureManager());
     ENCODE_CHK_NULL_RETURN(m_featureManager);
 
+    m_featureManager->SetUserSettingPtr(m_userSettingPtr);
+
     m_encodecp = MOS_New(EncodeCp, m_hwInterface);
     m_encodecp->RegisterParams(codecSettings);
     bool cpenable = m_encodecp->isCpEnabled();
@@ -187,6 +189,12 @@ MOS_STATUS EncodePipeline::UserFeatureReport()
         "Media Encode Used VDBOX Number",
         GetPipeNum(),
         MediaUserSetting::Group::Sequence);
+
+    ReportUserSettingForDebug(
+        m_userSettingPtr,
+        "Media Encode DDI TargetUsage",
+        GetDDITU(),
+        MediaUserSetting::Group::Sequence);
 #endif // _DEBUG || _RELEASE_INTERNAL
 
     return MOS_STATUS_SUCCESS;
