@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2022, Intel Corporation
+* Copyright (c) 2020-2024, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -30,10 +30,11 @@
 
 #include "codec_def_common_encode.h"
 #include "codec_def_common_av1.h"
+#include "codec_def_decode_av1.h"
 #include "mhw_vdbox.h"
 #include "mhw_vdbox_cmdpar.h"
 
-#ifdef IGFX_AVP_INTERFACE_EXT_SUPPORT
+#ifdef _MEDIA_RESERVED
 #include "mhw_vdbox_avp_cmdpar_ext.h"
 #define __MHW_VDBOX_AVP_WRAPPER(STUFF)
 #define __MHW_VDBOX_AVP_WRAPPER_EXT(STUFF) STUFF
@@ -115,6 +116,18 @@ struct AvpBufferSizePar
     uint32_t     curFrameTileNum;
     uint32_t     numTileCol;
     uint8_t      numOfActivePipes;
+    uint16_t     chromaFormat;
+};
+
+struct AvpVdboxRowStorePar
+{
+    uint32_t mode;
+    uint32_t picWidth;
+    uint32_t mbaff;
+    bool     isFrame;
+    uint8_t  bitDepthMinus8;
+    uint8_t  chromaFormat;
+    uint8_t  lcuSize;
 };
 
 struct _MHW_PAR_T(AVP_PIPE_MODE_SELECT)
@@ -239,6 +252,7 @@ struct _MHW_PAR_T(AVP_PIC_STATE)
 
     bool     allowScreenContentTools             = false;
     bool     allowIntraBC                        = false;
+    bool     VdaqmEnable                         = false;
 
     __MHW_VDBOX_AVP_WRAPPER_EXT(AVP_PIC_STATE_CMDPAR_EXT);
 };
@@ -277,7 +291,7 @@ struct _MHW_PAR_T(AVP_INLOOP_FILTER_STATE)
 struct _MHW_PAR_T(AVP_TILE_CODING)
 {
     uint16_t tileId                                  = 0;
-    uint16_t tileNum                                 = 0;  //!< Tile ID in its Tile group
+    uint16_t tgTileNum                                 = 0;  //!< Tile ID in its Tile group
     uint16_t tileGroupId                             = 0;
 
     uint16_t tileColPositionInSb                     = 0;
@@ -376,7 +390,7 @@ struct _MHW_PAR_T(AVP_PIPE_BUF_ADDR_STATE)
     PMOS_RESOURCE     filmGrainSampleTemplateBuffer    = nullptr;
     PMOS_RESOURCE     filmGrainOutputSurface           = nullptr;
 
-    PMOS_RESOURCE     rhoDomainThresholdTableBuffer    = nullptr;
+    PMOS_RESOURCE     AvpPipeBufAddrStatePar0          = nullptr;
 };
 
 struct _MHW_PAR_T(AVP_INTER_PRED_STATE)
