@@ -38,6 +38,7 @@
 const char * const MosUtilDebug::m_mosLogLevelName[MOS_MESSAGE_LVL_COUNT] = {
     "",          // DISABLED
     "CRITICAL",
+    "WARNING ",
     "NORMAL  ",
     "VERBOSE ",
     "ENTER   ",
@@ -232,6 +233,7 @@ void MosUtilDebug::MosMessageInitComponent(MOS_COMPONENT_ID compID, MediaUserSet
     const char                                  *bySubComponentsKey = nullptr;
     const char                                  *subComponentsKey = nullptr;
     MOS_STATUS                                  eStatus = MOS_STATUS_SUCCESS;
+    uint32_t                                    compLevel = 0;
 
     if (compID >= MOS_COMPONENT_COUNT )
     {
@@ -259,7 +261,17 @@ void MosUtilDebug::MosMessageInitComponent(MOS_COMPONENT_ID compID, MediaUserSet
     }
 
     // Extract the 3-bit message level and 1-bit assert flag setting for this component.
-    MosSetCompMessageLevel(compID, (MOS_MESSAGE_LEVEL) (uiCompUserFeatureSetting & 0x7));
+    // Extract the 4th bit message level to enable the WARNING message (take effect when log enabled)
+    compLevel = uiCompUserFeatureSetting & 0x7;
+    if (compLevel > 1)
+    {
+        compLevel = compLevel + 1;
+    }
+    else if ((uiCompUserFeatureSetting & 0x10) && (compLevel == 1))
+    {
+        compLevel = 2;
+    }
+    MosSetCompMessageLevel(compID, (MOS_MESSAGE_LEVEL) compLevel);
     MosCompAssertEnableDisable(compID, (uiCompUserFeatureSetting >> 3) & 0x1);
 
     // Check if sub-components should be set seperately.
@@ -303,10 +315,20 @@ void MosUtilDebug::MosMessageInitComponent(MOS_COMPONENT_ID compID, MediaUserSet
         {
             // Extract the 3-bit message level and 1-bit assert flag setting for each sub-comp
             // from the user feature key and populate to the MOS message params structure
-            MosSetSubCompMessageLevel(compID, i, (MOS_MESSAGE_LEVEL)(uiSubCompUserFeatureSetting & 0x7));
+            // Extract the 4th bit message level to enable the WARNING message (take effect when log enabled)
+            compLevel = uiSubCompUserFeatureSetting & 0x7;
+            if (compLevel > 1)
+            {
+                compLevel = compLevel + 1;
+            }
+            else if ((uiSubCompUserFeatureSetting & 0x10) && (compLevel == 1))
+            {
+                compLevel = 2;
+            }
+            MosSetSubCompMessageLevel(compID, i, (MOS_MESSAGE_LEVEL)compLevel);
             MosSubCompAssertEnableDisable(compID, i, (uiSubCompUserFeatureSetting >> 3) & 0x1);
 
-            uiSubCompUserFeatureSetting = (uiSubCompUserFeatureSetting >> 4);
+            uiSubCompUserFeatureSetting = (uiSubCompUserFeatureSetting >> 5);
         }
     }
 }
@@ -317,6 +339,8 @@ MOS_STATUS MosUtilDebug::MosHLTInit(MediaUserSettingSharedPtr userSettingPtr)
     char                                        hltFileName[MOS_MAX_HLT_FILENAME_LEN] = {0};
     char                                        fileNamePrefix[MOS_MAX_HLT_FILENAME_LEN];
     int32_t                                     bUseHybridLogTrace = false;
+    int32_t                                     bEnableFlush = false;
+    int32_t                                     bEnableMemoryFootPrint = false;
     MOS_STATUS                                  eStatus = MOS_STATUS_SUCCESS;
 
     if (m_mosMsgParams.uiCounter != 0 )
@@ -325,9 +349,49 @@ MOS_STATUS MosUtilDebug::MosHLTInit(MediaUserSettingSharedPtr userSettingPtr)
         return MOS_STATUS_UNKNOWN;
     }
 
+    
+    eStatus = ReadUserSetting(
+        userSettingPtr,
+        bEnableFlush,
+        __MOS_USER_FEATURE_KEY_FLUSH_LOG_FILE_BEFORE_SUBMISSION,
+        MediaUserSetting::Group::Device);
+
+
+    ReportUserSetting(
+        userSettingPtr,
+        __MOS_USER_FEATURE_KEY_FLUSH_LOG_FILE_BEFORE_SUBMISSION,
+        bEnableFlush,
+        MediaUserSetting::Group::Device);
+
+    if (!bEnableFlush)
+    {
+        MOS_OS_NORMALMESSAGE("HLT flush is not enabled.");
+    }
+
     m_mosMsgParams.bUseHybridLogTrace = false;
     m_mosMsgParams.pLogFile           = nullptr;
     m_mosMsgParams.pTraceFile         = nullptr;
+    m_mosMsgParams.bEnableFlush       = bEnableFlush;
+
+    // disable memory foot print
+    eStatus = ReadUserSetting(
+        userSettingPtr,
+        bEnableMemoryFootPrint,
+        __MOS_USER_FEATURE_KEY_ENABLE_MEMORY_FOOT_PRINT,
+        MediaUserSetting::Group::Device);
+
+    ReportUserSetting(
+        userSettingPtr,
+        __MOS_USER_FEATURE_KEY_ENABLE_MEMORY_FOOT_PRINT,
+        bEnableMemoryFootPrint,
+        MediaUserSetting::Group::Device);
+
+    if (bEnableMemoryFootPrint)
+    {
+        MOS_OS_NORMALMESSAGE("Mos memory foot print is enabled.");
+    }
+
+    m_mosMsgParams.bEnableMemoryFootPrint = bEnableMemoryFootPrint;
 
     // Check if HLT should be enabled.
     eStatus = ReadUserSetting(
@@ -345,7 +409,7 @@ MOS_STATUS MosUtilDebug::MosHLTInit(MediaUserSettingSharedPtr userSettingPtr)
             MediaUserSetting::Group::Device);
     }
 
-    bUseHybridLogTrace = MosUtilities::m_mosUltFlag ? 1 : bUseHybridLogTrace;
+    bUseHybridLogTrace = (MosUtilities::m_mosUltFlag && *MosUtilities::m_mosUltFlag) ? 1 : bUseHybridLogTrace;
 
     // Dumping memory mapped regions to trace file disabled for now
     // Need to add new user feature key or derive from the above key.
@@ -357,7 +421,7 @@ MOS_STATUS MosUtilDebug::MosHLTInit(MediaUserSettingSharedPtr userSettingPtr)
         return MOS_STATUS_SUCCESS;               //[SH]: Check this.
     }
 
-    nPID = MosUtilities::m_mosUltFlag ? 0 : MosUtilities::MosGetPid();
+    nPID = (MosUtilities::m_mosUltFlag && *MosUtilities::m_mosUltFlag) ? 0 : MosUtilities::MosGetPid();
 
     // Get logfile directory.
     MosLogFileNamePrefix(fileNamePrefix, userSettingPtr);
@@ -452,7 +516,7 @@ void MosUtilDebug::MosMessageInit(MediaUserSettingSharedPtr userSettingPtr)
                 MediaUserSetting::Group::Device);
         }
 
-        if (MosUtilities::m_mosUltFlag)
+        if (MosUtilities::m_mosUltFlag && (*MosUtilities::m_mosUltFlag))
         {
             MosSetCompMessageLevelAll(MOS_MESSAGE_LVL_DISABLED);
             MosSetCompMessageLevel(MOS_COMPONENT_OS, MOS_MESSAGE_LVL_CRITICAL);
@@ -466,9 +530,19 @@ void MosUtilDebug::MosMessageInit(MediaUserSettingSharedPtr userSettingPtr)
         MosHLTInit(userSettingPtr);
 
         // all above action should not be covered by memninja since its destroy is behind memninja counter report to test result.
-        MosUtilities::m_mosMemAllocCounter     = 0;
-        MosUtilities::m_mosMemAllocFakeCounter = 0;
-        MosUtilities::m_mosMemAllocCounterGfx  = 0;
+        if (MosUtilities::m_mosMemAllocCounter &&
+            MosUtilities::m_mosMemAllocCounterGfx &&
+            MosUtilities::m_mosMemAllocFakeCounter)
+        {
+            *MosUtilities::m_mosMemAllocCounter     = 0;
+            *MosUtilities::m_mosMemAllocFakeCounter = 0;
+            *MosUtilities::m_mosMemAllocCounterGfx  = 0;
+        }
+        else
+        {
+            MOS_OS_ASSERTMESSAGE("MemNinja count pointers are nullptr");
+        }
+
         MOS_OS_VERBOSEMESSAGE("MemNinja leak detection begin");
     }
 
@@ -511,6 +585,43 @@ void MosUtilDebug::MosMessageClose()
     }
 }
 
+void MosUtilDebug::MosHLTFlush()
+{
+    if (!m_mosMsgParams.bEnableFlush)
+    {
+        return;
+    }
+
+    MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+    if (m_mosMsgParams.pLogFile != nullptr)
+    {
+#if COMMON_DLL_SEPARATION_SUPPORT
+        // Every DLL has its own C Runtime (CRT),
+        // and fflush is not safe across dlls.
+        // When common dll separation is enabled, We should call back into common dll for all DDI dlls.
+        MosUtilities::MosFlushToFileInCommon(m_mosMsgParams.pLogFile);
+#else
+        fflush(m_mosMsgParams.pLogFile);
+#endif
+    }
+    if (m_mosMsgParams.pTraceFile != nullptr)
+    {
+#if COMMON_DLL_SEPARATION_SUPPORT
+        // Every DLL has its own C Runtime (CRT),
+        // and fflush is not safe across dlls.
+        // When common dll separation is enabled, We should call back into common dll for all DDI dlls.
+        MosUtilities::MosFlushToFileInCommon(m_mosMsgParams.pTraceFile);
+#else
+        fflush(m_mosMsgParams.pTraceFile);
+#endif
+    }
+}
+
+bool MosUtilDebug::EnableMemoryFootPrint()
+{
+    return m_mosMsgParams.bEnableMemoryFootPrint;
+}
+
 void MosUtilDebug::MosMessage(
     MOS_MESSAGE_LEVEL level,
     MOS_COMPONENT_ID  compID,
