@@ -1064,6 +1064,15 @@ MOS_STATUS BltStateNext::SetPrologParamsforCmdbuffer(PMOS_COMMAND_BUFFER cmdBuff
            cmdBuffer->Attributes.dwMediaFrameTrackingAddrOffset = GenericPrologParams.dwMediaFrameTrackingAddrOffset;
            cmdBuffer->Attributes.resMediaFrameTrackingSurface   = GenericPrologParams.presMediaFrameTrackingSurface;
    }
+   if (pOsInterface->pfnIsGpuSyncByCmd(pOsInterface, pOsInterface->CurrentGpuContextHandle) && cmdBuffer->syncMhwBatchBuffer != nullptr)  // Some gpu context may not support sync with batch buffer
+   {
+           //Reset params
+           auto &miBatchBufferStartParams = m_miItf->MHW_GETPAR_F(MI_BATCH_BUFFER_START)();
+           miBatchBufferStartParams       = {};
+           uint64_t gfxAddr = pOsInterface->pfnGetResourceGfxAddress(pOsInterface, &cmdBuffer->OsResource);
+           pOsInterface->pfnOnNativeFenceSyncBBAdded(cmdBuffer, gfxAddr);
+           MHW_CHK_STATUS_RETURN(m_miItf->MHW_ADDCMD_F(MI_BATCH_BUFFER_START)(cmdBuffer, cmdBuffer->syncMhwBatchBuffer));
+   }
 
    return eStatus;
 }
