@@ -50,7 +50,11 @@ MediaPipeline::MediaPipeline(PMOS_INTERFACE osInterface) : m_osInterface(osInter
     }
     else
     {
-        perfProfiler->Initialize((void *)this, m_osInterface);
+        MOS_STATUS status = perfProfiler->Initialize((void *)this, m_osInterface);
+        if (status != MOS_STATUS_SUCCESS)
+        {
+            MOS_OS_ASSERTMESSAGE("Initialize perfProfiler failed!");
+        }
     }
 }
 
@@ -60,9 +64,9 @@ MediaPipeline::~MediaPipeline()
     DeleteTasks();
 
     MOS_Delete(m_mediaCopyWrapper);
-
+#if !EMUL
     MEDIA_DEBUG_TOOL(MOS_Delete(m_debugInterface));
-
+#endif
     MediaPerfProfiler *perfProfiler = MediaPerfProfiler::Instance();
 
     if (!perfProfiler)
@@ -134,7 +138,7 @@ MOS_STATUS MediaPipeline::RegisterPacket(uint32_t packetId, MediaPacket *packet)
     {
         m_packetList.erase(iter);
     }
-    m_packetList.insert(std::make_pair(packetId, packet));
+    m_packetList.emplace(packetId, packet);
 
     return MOS_STATUS_SUCCESS;
 }
@@ -150,12 +154,20 @@ MediaPacket *MediaPipeline::GetOrCreate(uint32_t packetId)
     auto iterCreator = m_packetCreators.find(packetId);
     if (iterCreator != m_packetCreators.end())
     {
-        RegisterPacket(packetId, iterCreator->second());
+        MOS_STATUS registStatus = RegisterPacket(packetId, iterCreator->second());
+        if (MOS_FAILED(registStatus))
+        {
+            MOS_OS_ASSERTMESSAGE("Media register packets into packet pool failed!");
+        }
 
         iter = m_packetList.find(packetId);
         if (iter != m_packetList.end())
         {
-            iter->second->Init();
+            MOS_STATUS status = iter->second->Init();
+            if (MOS_FAILED(status))
+            {
+                MOS_OS_ASSERTMESSAGE("Media packet init failed!");
+            }
             return iter->second;
         }
     }
@@ -245,7 +257,7 @@ MediaTask *MediaPipeline::CreateTask(MediaTask::TaskType type)
     }
     if (nullptr != task)
     {
-        m_taskList.insert(std::make_pair(type, task));
+        m_taskList.emplace(type, task);
     }
     return task;
 }
