@@ -67,7 +67,7 @@ MOS_STATUS HwFilterPipeFactory::Destory(HwFilterPipe *&pHwfilterPipe)
 /*                                      HwFilterFactory                                             */
 /****************************************************************************************************/
 
-HwFilterFactory::HwFilterFactory(VpInterface &vpInterface) : m_allocatorVebox(vpInterface), m_allocatorVeboxSfc(vpInterface), m_allocatorRender(vpInterface)
+HwFilterFactory::HwFilterFactory(VpInterface &vpInterface) : m_allocatorVebox(vpInterface), m_allocatorVeboxSfc(vpInterface), m_allocatorRender(vpInterface), m_allocatorNpu(vpInterface)
 {
 }
 
@@ -91,6 +91,9 @@ HwFilter *HwFilterFactory::Create(HW_FILTER_PARAMS &param)
     case EngineTypeRender:
         p = m_allocatorRender.Create();
         break;
+    case EngineTypeNpu:
+        p = m_allocatorNpu.Create();
+        break;
     default:
         return nullptr;
         break;
@@ -159,6 +162,21 @@ void HwFilterFactory::Destory(HwFilter *&pHwFilter)
             }
             break;
         }
+        case EngineTypeNpu:
+        {
+            HwFilterNpu *p = dynamic_cast<HwFilterNpu *>(pHwFilter);
+            if (p)
+            {
+                m_allocatorNpu.Destory(p);
+                pHwFilter = nullptr;
+            }
+            else
+            {
+                VP_PUBLIC_ASSERTMESSAGE("Invalid engine type for hwFilter!");
+                MOS_Delete(pHwFilter);
+            }
+            break;
+        }
         default:
             MOS_Delete(pHwFilter);
             return;
