@@ -498,6 +498,34 @@ struct _RENDER_OCL_FC_PARAMS
 using RENDER_OCL_FC_PARAMS  = _RENDER_OCL_FC_PARAMS;
 using PRENDER_OCL_FC_PARAMS = RENDER_OCL_FC_PARAMS *;
 
+struct AI_KERNEL_CONFIG
+{
+    VPHAL_PERFTAG            perfTag     = VPHAL_NONE;
+};
+
+struct AI_KERNEL_PARAM
+{
+    KERNEL_ARGS                  kernelArgs;
+    std::string                  kernelName;
+    uint32_t                     threadWidth;
+    uint32_t                     threadHeight;
+    uint32_t                     threadDepth;
+    uint32_t                     localWidth;
+    uint32_t                     localHeight;
+    KERNEL_ARG_INDEX_SURFACE_MAP kernelStatefulSurfaces;
+    void                         Init();
+};
+
+using AI_KERNEL_PARAMS = std::vector<AI_KERNEL_PARAM>;
+struct _RENDER_AI_PARAMS
+{
+    AI_KERNEL_PARAMS ai_kernelParams = {};
+    AI_KERNEL_CONFIG ai_kernelConfig = {};
+    void             Init();
+};
+using RENDER_AI_PARAMS  = _RENDER_AI_PARAMS;
+using PRENDER_AI_PARAMS = RENDER_AI_PARAMS *;
+
 struct _RENDER_HDR_PARAMS
 {
     VpKernelID              kernelId;
