@@ -49,6 +49,7 @@ public:
     }
 
     MOS_STATUS SetEuThreadSchedulingMode(uint32_t mode);
+    MOS_STATUS SetLargeGrfMode(uint32_t mode);
 
     virtual MOS_STATUS Submit(MOS_COMMAND_BUFFER* commandBuffer, uint8_t packetPhase = otherPacket) override;
 
@@ -67,7 +68,9 @@ public:
 
     virtual MOS_STATUS SetDnHVSParams(PRENDER_DN_HVS_CAL_PARAMS params);
 
-    virtual MOS_STATUS SetL0FcParams(PRENDER_L0_FC_PARAMS params);
+    virtual MOS_STATUS SetOclFcParams(PRENDER_OCL_FC_PARAMS params);
+
+    virtual MOS_STATUS SetAiParams(PRENDER_AI_PARAMS params);
 
     virtual MOS_STATUS DumpOutput() override;
 
@@ -91,6 +94,8 @@ protected:
 
     virtual MOS_STATUS SetupCurbeState();
 
+    virtual MOS_STATUS SetupCurbeStateInBindlessMode();
+
     virtual VP_SURFACE* GetSurface(SurfaceType type);
 
     virtual MOS_STATUS SetupWalkerParams();
@@ -159,8 +164,6 @@ protected:
 protected:
 
     KERNEL_OBJECTS                     m_kernelObjs;
-    // Only for MULTI_KERNELS_WITH_ONE_MEDIA_STATE case.
-    KERNEL_RENDER_DATA                 m_kernelRenderData;
 
     KERNEL_CONFIGS                     m_kernelConfigs; // Kernel parameters for legacy kernels.
 
@@ -172,7 +175,6 @@ protected:
     KERNEL_SAMPLER_STATE_GROUP         m_kernelSamplerStateGroup;
 
     KERNEL_SUBMISSION_MODE             m_submissionMode   = SINGLE_KERNEL_ONLY;
-    uint32_t                           m_slmSize          = 0;
     uint32_t                           m_totalCurbeSize   = 0;
     uint32_t                           m_totoalInlineSize = 0;
 
