@@ -26,6 +26,7 @@
 #include "sw_filter.h"
 #include "media_render_cmd_packet.h"
 #include "vp_platform_interface.h"
+#include "vpkrnheader.h"
 #include <vector>
 #include <map>
 #include <set>
@@ -86,9 +87,8 @@ using KERNEL_SAMPLER_STATES = std::vector<MHW_SAMPLER_STATE_PARAM>;
 using KERNEL_SAMPLER_INDEX = std::vector<SamplerIndex>;
 using KERNEL_SURFACE_CONFIG = std::map<SurfaceType, KERNEL_SURFACE_STATE_PARAM>;
 using KERNEL_SURFACE_BINDING_INDEX = std::map<SurfaceType, std::set<uint32_t>>;
-using KERNEL_STATELESS_BUFF_CONFIG = std::map<SurfaceType, uint64_t>;
-using KERNEL_BINDELESS_SURFACE = std::map<SurfaceType, std::set<uint32_t>>;
-using KERNEL_BINDELESS_SAMPLER = std::map<uint32_t, uint32_t>;
+using KERNEL_BINDELESS_SURFACE = std::map<SurfaceType, std::vector<RENDERHAL_STATE_LOCATION>>;
+using KERNEL_BINDELESS_SAMPLER = std::map<uint32_t, RENDERHAL_STATE_LOCATION>;
 
 typedef struct _KERNEL_PARAMS
 {
@@ -99,6 +99,7 @@ typedef struct _KERNEL_PARAMS
     bool                         flushL1;
     KERNEL_TUNING_PARAMS         kernelTuningParams;
     KERNEL_ARG_INDEX_SURFACE_MAP kernelStatefulSurfaces;
+    std::string                  kernelName;
 } KERNEL_PARAMS;
 
 struct MEDIA_OBJECT_KA2_INLINE_DATA
@@ -459,7 +460,7 @@ public:
         {
             std::set<uint32_t> bindingMap;
             bindingMap.insert(index);
-            m_surfaceBindingIndex.insert(std::make_pair(surface, bindingMap));
+            m_surfaceBindingIndex.emplace(surface, bindingMap);
         }
 
         return MOS_STATUS_SUCCESS;
@@ -473,7 +474,7 @@ public:
         {
             VP_RENDER_ASSERTMESSAGE("No surface index created for current surface");
             std::set<uint32_t> bindingMap;
-            it = m_surfaceBindingIndex.insert(std::make_pair(surface, bindingMap)).first;
+            it = m_surfaceBindingIndex.emplace(surface, bindingMap).first;
         }
         return it->second;
     }
@@ -524,21 +525,34 @@ public:
         return 0;
     }
 
+    virtual uint32_t GetLargeGrfMode()
+    {
+        //by default not enable
+        //control all the kernels in BB, cannot only enable for one kernel in BB
+        return 0;
+    }
+
     virtual MOS_STATUS InitRenderHalSurfaceCMF(MOS_SURFACE* src, PRENDERHAL_SURFACE renderHalSurface);
 
-    virtual MOS_STATUS SetInlineDataParameter(KRN_ARG args, RENDERHAL_INTERFACE *renderhal);
-
-    virtual MOS_STATUS UpdateBindlessSurfaceResource(SurfaceType surf, std::set<uint32_t> surfStateOffset)
+    virtual MOS_STATUS UpdateBindlessSurfaceResource(SurfaceType surf, std::vector<RENDERHAL_STATE_LOCATION> stateLocations)
     {
-        if (surf != SurfaceTypeInvalid)
+        if (surf != SurfaceTypeInvalid && surf != SurfaceTypeSubPlane)
         {
-            m_bindlessSurfaceArray.insert(std::make_pair(surf, surfStateOffset));
+            auto handle = m_bindlessSurfaceArray.find(surf);
+            if (handle == m_bindlessSurfaceArray.end())
+            {
+                m_bindlessSurfaceArray.insert(std::make_pair(surf, stateLocations));
+            }
+            else
+            {
+                handle->second = stateLocations;
+            }
         }
 
         return MOS_STATUS_SUCCESS;
     }
 
-    virtual std::map<uint32_t, uint32_t>& GetBindlessSamplers()
+    virtual KERNEL_BINDELESS_SAMPLER &GetBindlessSamplers()
     {
         return m_bindlessSamperArray;
     }
@@ -550,6 +564,8 @@ public:
         return MOS_STATUS_SUCCESS;
     }
 
+    MOS_STATUS UpdateCurbeStateHeapInfo(PMOS_RESOURCE stateHeap, uint8_t *statePtr, uint32_t offset);
+
 protected:
 
     virtual MOS_STATUS SetWalkerSetting(KERNEL_THREAD_SPACE &threadSpace, bool bSyncFlag, bool flushL1 = false);
@@ -566,10 +582,6 @@ protected:
 
     virtual MOS_STATUS CpPrepareResources();
 
-    virtual MOS_STATUS SetupStatelessBuffer();
-
-    virtual MOS_STATUS SetupStatelessBufferResource(SurfaceType surf);
-
     virtual MOS_STATUS GetCurbeState(void *&curbe, uint32_t &curbeLength) = 0;
 
     virtual MOS_STATUS GetAlignedLength(uint32_t &curbeLength, uint32_t &curbeLengthAligned, RENDERHAL_KERNEL_PARAM kernelParam, uint32_t dwBlockAlign)
@@ -580,6 +592,17 @@ protected:
 
     virtual MOS_STATUS SetTuningFlag(PKERNEL_TUNING_PARAMS tuningParams);
 
+    virtual MOS_STATUS SetInlineDataParameter(KRN_ARG arg, uint8_t *inlineData);
+
+    virtual MOS_STATUS SetBindlessSamplerToResourceList(KRN_ARG &arg, uint32_t samplerIndex);
+    virtual MOS_STATUS SetBindlessSurfaceStateToResourceList(KRN_ARG &arg);
+
+    bool IsLocalIdGeneratedByRuntime(KRN_EXECUTE_ENV &krnEnv, KRN_PER_THREAD_ARG_INFO &perThreadInfo, uint32_t localWidth, uint32_t localHeight, uint32_t localDepth);
+
+    MOS_STATUS PaddingPerThreadCurbe(uint32_t &curbeSize, uint32_t localWidth, uint32_t localHeight, uint32_t localDepth);
+
+    MOS_STATUS SetPerThreadCurbe(uint8_t *curbe, uint32_t offset, uint32_t curbeSize, KRN_PER_THREAD_ARG_INFO &perThreadInfo, uint32_t localWidth, uint32_t localHeight, uint32_t localDepth);
+
 protected:
 
     VP_SURFACE_GROUP                                        *m_surfaceGroup = nullptr;  // input surface process surface groups
@@ -588,25 +611,30 @@ protected:
     KERNEL_SURFACE_BINDING_INDEX                            m_surfaceBindingIndex;      // store the binding index for processed surface
     PVpAllocator                                            m_allocator = nullptr;
     MediaUserSettingSharedPtr                               m_userSettingPtr = nullptr;  // usersettingInstance
-    KERNEL_STATELESS_BUFF_CONFIG                            m_statelessArray;
     KERNEL_BINDELESS_SURFACE                                m_bindlessSurfaceArray;
     KERNEL_BINDELESS_SAMPLER                                m_bindlessSamperArray;
+    std::vector<MHW_INDIRECT_STATE_RESOURCE_PARAMS>         m_curbeResourceList  = {};
+    std::vector<MHW_INDIRECT_STATE_RESOURCE_PARAMS>         m_inlineResourceList = {};
     // kernel attribute 
     std::string                                             m_kernelName = "";
     void *                                                  m_kernelBinary = nullptr;
     uint32_t                                                m_kernelBinaryID = 0;
     uint32_t                                                m_kernelSize = 0;
+    uint32_t                                                m_kernelPaddingSize = 0;
     VpKernelID                                              m_kernelId = kernelCombinedFc;
     DelayLoadedKernelType                                   m_kernelType     = KernelNone;
     KernelIndex                                             m_kernelIndex = 0;          // index of current kernel in KERNEL_PARAMS_LIST
 
+    RENDERHAL_STATE_LOCATION                                m_curbeLocation     = {};
+
     PKERNEL_TUNING_PARAMS                                   m_kernelTuningParams = nullptr;
 
     bool                                                    m_isAdvKernel = false;      // true mean multi kernel can be submitted in one workload.
     bool                                                    m_useIndependentSamplerGroup = false; //true means multi kernels has their own stand alone sampler states group. only can be true when m_isAdvKernel is true.
 
     std::shared_ptr<mhw::vebox::Itf>                        m_veboxItf = nullptr;
-    std ::vector<MHW_INLINE_DATA_PARAMS>                    m_inlineDataParams = {};
+
+    KERNEL_ARG_INDEX_SURFACE_MAP                            m_argIndexSurfMap = {};
 
 MEDIA_CLASS_DEFINE_END(vp__VpRenderKernelObj)
 };
