@@ -236,6 +236,10 @@
 #define VP_VEBOX_HDR_3DLUT65                                        LUT65_SEG_SIZE *\
                                                                     LUT65_SEG_SIZE *\
                                                                     LUT65_MUL_SIZE * sizeof(int64_t)
+#define VP_VEBOX_HDR_3DLUT33                                        LUT33_SEG_SIZE *             \
+                                                                    LUT33_SEG_SIZE *     \
+                                                                    LUT33_MUL_SIZE * \
+                                                                    sizeof(int64_t)
 #define SHAPE_1K_LOOKUP_SIZE                                        2048 * sizeof(uint32_t)
 //!
 //! \brief Vebox Statistics Surface definition
@@ -298,6 +302,7 @@ typedef struct _VEBOX_PACKET_SURFACE_PARAMS
     VP_SURFACE                      *pLaceOrAceOrRgbHistogram;
     VP_SURFACE                      *pSurfSkinScoreOutput;
     VP_SURFACE                      *pFMDHistorySurface;
+    VP_SURFACE                      *pInnerTileConvertInput;
 }VEBOX_PACKET_SURFACE_PARAMS, *PVEBOX_PACKET_SURFACE_PARAMS;
 };
 
@@ -452,6 +457,26 @@ public:
     //! \return   MOS_STATUS
     //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
     //!
+    virtual MOS_STATUS SetVeboxCSCParams(PVEBOX_CSC_PARAMS cscParams) override;
+
+    //!
+    //! \brief    Setup CSC Params for Vebox front end
+    //! \details  Setup surface CSC Params for Vebox
+    //! \param    [in] cscParams
+    //!           CSC Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
+    virtual MOS_STATUS SetVeboxFeCSCParams(PVEBOX_CSC_PARAMS cscParams) override;
+
+     //!
+    //! \brief    Setup CSC Params for Vebox
+    //! \details  Setup surface CSC Params for Vebox
+    //! \param    [in] cscParams
+    //!           CSC Params
+    //! \return   MOS_STATUS
+    //!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+    //!
     virtual MOS_STATUS SetVeboxBeCSCParams(PVEBOX_CSC_PARAMS cscParams) override;
 
     //!
@@ -917,6 +942,16 @@ public:
         uint32_t *pStatSlice0GNEPtr,
         uint32_t *pStatSlice1GNEPtr);
 
+    MOS_STATUS InitVeboxSurfaceStateCmdParamsForTileConvert(
+        PMHW_VEBOX_SURFACE_STATE_CMD_PARAMS mhwVeboxSurfaceStateCmdParams,
+        PMOS_SURFACE                        inputSurface,
+        PMOS_SURFACE                        outputSurface);
+
+    MOS_STATUS AddTileConvertStates(
+        MOS_COMMAND_BUFFER *CmdBuffer,
+        MHW_VEBOX_SURFACE_STATE_CMD_PARAMS &MhwVeboxSurfaceStateCmdParams);
+
+    MOS_FORMAT AdjustFormatForTileConvert(MOS_FORMAT format);
     // TGNE
     uint32_t dwGlobalNoiseLevel_Temporal  = 0;  //!< Global Temporal Noise Level for Y
     uint32_t dwGlobalNoiseLevelU_Temporal = 0;  //!< Global Temporal Noise Level for U
@@ -926,6 +961,7 @@ public:
     uint32_t curNoiseLevelV_Temporal      = 0;  //!< Temporal Noise Level for V
     bool     m_bTgneEnable                = true;
     bool     m_bTgneValid                 = false;
+    bool     m_bFallback                  = false;
 
     mhw::vebox::MHW_VEBOX_CHROMA_PARAMS veboxChromaParams = {};
 
@@ -935,6 +971,14 @@ public:
     {
         return MOS_STATUS_SUCCESS;
     }
+
+    virtual MOS_STATUS StoreCSEngineIdRegMem(
+        MOS_COMMAND_BUFFER *cmdBuffer,
+        const MHW_VEBOX_HEAP *veboxHeap)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
 #endif
 
 protected:
@@ -1118,8 +1162,19 @@ protected:
         mhw::vebox::VEBOX_STATE_PAR &veboxStateCmdParams);
     virtual MOS_STATUS Init3DLutTable(PVP_SURFACE surf3DLut);
     void    UpdateCpPrepareResources();
+    virtual MOS_STATUS Add1DLutState(PVP_SURFACE &surface, PMHW_1DLUT_PARAMS p1DLutParams);
     virtual MOS_STATUS SetupVebox3DLutForHDR(
         mhw::vebox::VEBOX_STATE_PAR &veboxStateCmdParams);
+    virtual MOS_STATUS SetupVeboxFP16State(mhw::vebox::VEBOX_STATE_PAR &veboxStateCmdParams)
+    {
+        return MOS_STATUS_SUCCESS;
+    }
+
+    virtual MOS_STATUS SetupHDRUnifiedForHDR(
+        mhw::vebox::VEBOX_STATE_PAR &veboxStateCmdParams);
+
+    virtual MOS_STATUS SetupVeboxExternal3DLutforHDR(
+        mhw::vebox::VEBOX_STATE_PAR &veboxStateCmdParams);
 
 private:
 
@@ -1187,6 +1242,7 @@ protected:
     VP_SURFACE                  *m_currentSurface           = nullptr;              //!< Current frame
     VP_SURFACE                  *m_previousSurface          = nullptr;              //!< Previous frame
     VP_SURFACE                  *m_renderTarget             = nullptr;              //!< Render Target frame
+    VP_SURFACE                  *m_originalOutput           = nullptr;              //!< Render Target frame
 
     uint32_t                    m_dwGlobalNoiseLevelU = 0;                        //!< Global Noise Level for U
     uint32_t                    m_dwGlobalNoiseLevelV = 0;                        //!< Global Noise Level for V
