@@ -21,7 +21,7 @@
 */
 #include "vp_pipeline_adapter.h"
 #include "vp_platform_interface.h"
-#include "vphal_debug.h"
+#include "vp_debug.h"
 #include "vp_user_feature_control.h"
 
 VpPipelineAdapter::VpPipelineAdapter(
@@ -47,7 +47,7 @@ VpPipelineAdapter::~VpPipelineAdapter()
 };
 
 MOS_STATUS VpPipelineAdapter::Init(
-    const VphalSettings *pVpHalSettings, VP_MHWINTERFACE vpMhwinterface)
+    const VpSettings *pVpHalSettings, VP_MHWINTERFACE vpMhwinterface)
 {
     VP_FUNC_CALL();
 
@@ -86,6 +86,11 @@ MOS_STATUS VpPipelineAdapter::Init(
     RENDERHAL_SETTINGS RenderHalSettings;
     RenderHalSettings.iMediaStates = pVpHalSettings->mediaStates;
     VP_PUBLIC_CHK_STATUS_RETURN(vpMhwinterface.m_renderHal->pfnInitialize(vpMhwinterface.m_renderHal, &RenderHalSettings));
+    if (m_vpPlatformInterface.GetKernelConfig() &&
+        m_vpPlatformInterface.GetKernelConfig()->GetRenderEnlargeOverwriteParams().needOverwrite)
+    {
+        VP_PUBLIC_CHK_STATUS_RETURN(vpMhwinterface.m_renderHal->pfnOverwriteEnlargedHeapParams(vpMhwinterface.m_renderHal, m_vpPlatformInterface.GetKernelConfig()->GetRenderEnlargeOverwriteParams().params));
+    }
     vpMhwinterface.m_renderHal->sseuTable = VpHalDefaultSSEUTable;
 
     return m_vpPipeline->Init(&vpMhwinterface);
