@@ -138,7 +138,7 @@ MOS_STATUS VpPlatformInterface::InitVPFCKernels(
             patchKernelSize,
             ModifyFunctionPointers);
 
-        m_kernelPool.insert(std::make_pair(vpKernel.GetKernelName(), vpKernel));
+        m_kernelPool.emplace(vpKernel.GetKernelName(), vpKernel);
     }
 
     return MOS_STATUS_SUCCESS;
@@ -196,7 +196,7 @@ MOS_STATUS VpPlatformInterface::InitPolicyRules(VP_POLICY_RULES &rules)
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpRenderKernel::SetKernelName(std::string kernelname)
+MOS_STATUS VpRenderKernel::SetKernelName(const std::string &kernelname)
 {
     VP_FUNC_CALL();
     m_kernelName.assign(kernelname);
@@ -260,7 +260,7 @@ void VpPlatformInterface::AddVpIsaKernelEntryToList(
     else
     {
         m_vpDelayLoadedBinaryList.push_back(tmpEntry);
-        m_vpDelayLoadedFeatureSet.insert(std::make_pair(delayKernelType, false));
+        m_vpDelayLoadedFeatureSet.emplace(delayKernelType, false);
     }
 }
 
@@ -275,7 +275,7 @@ void VpPlatformInterface::AddVpNativeAdvKernelEntryToList(
     tmpEntry.kernelBin     = kernelBin;
     tmpEntry.kernelBinSize = kernelBinSize;
 
-    m_vpNativeAdvKernelBinaryList.insert(std::make_pair(kernelName, tmpEntry));
+    m_vpNativeAdvKernelBinaryList.emplace(kernelName, tmpEntry);
 }
 
 void VpPlatformInterface::InitVpDelayedNativeAdvKernel(
@@ -296,7 +296,7 @@ void VpPlatformInterface::AddNativeAdvKernelToDelayedList(
     DelayLoadedFunc       func)
 {
     VP_FUNC_CALL();
-    m_vpDelayLoadedNativeFunctionSet.insert(std::make_pair(kernelType, func));
+    m_vpDelayLoadedNativeFunctionSet.emplace(kernelType, func);
 }
 
 void       KernelDll_ModifyFunctionPointers_Next(Kdll_State *pState);
@@ -339,13 +339,13 @@ MOS_STATUS VpPlatformInterface::InitVpRenderHwCaps()
         // Init native adv kernel form VP Native adv kernel Binary List
         for (auto &curKernelEntry : m_vpNativeAdvKernelBinaryList)
         {
-            VP_PUBLIC_CHK_STATUS_RETURN(InitVpNativeAdvKernels(curKernelEntry.first, curKernelEntry.second));
+            InitVpNativeAdvKernels(curKernelEntry.first, curKernelEntry.second);
         }
     }
     return MOS_STATUS_SUCCESS;
 }
 
-MOS_STATUS VpPlatformInterface::InitVpNativeAdvKernels(
+void VpPlatformInterface::InitVpNativeAdvKernels(
     std::string            kernelName,
     VP_KERNEL_BINARY_ENTRY kernelBinaryEntry)
 {
@@ -357,9 +357,9 @@ MOS_STATUS VpPlatformInterface::InitVpNativeAdvKernels(
     vpKernel.SetKernelName(kernelName);
     vpKernel.SetKernelBinOffset(0x0);
     vpKernel.SetKernelBinSize(kernelBinaryEntry.kernelBinSize);
-    m_kernelPool.insert(std::make_pair(vpKernel.GetKernelName(), vpKernel));
+    m_kernelPool.emplace(vpKernel.GetKernelName(), vpKernel);
 
-    return MOS_STATUS_SUCCESS;
+    return;
 }
 
 MOS_STATUS VpPlatformInterface::InitVpCmKernels(
@@ -522,7 +522,7 @@ MOS_STATUS VpPlatformInterface::InitVpCmKernels(
             vpKernel.AddKernelArg(kernelArg);
         }
 
-        m_kernelPool.insert(std::make_pair(vpKernel.GetKernelName(), vpKernel));
+        m_kernelPool.emplace(vpKernel.GetKernelName(), vpKernel);
     }
 
     MOS_Delete(isaFile);
@@ -546,6 +546,12 @@ VpPlatformInterface::~VpPlatformInterface()
     {
         m_vpDelayLoadedNativeFunctionSet.clear();
     }
+
+    if (m_frameTracker)
+    {
+        MOS_Delete(m_frameTracker);
+    }
+
 }
 
 MOS_STATUS VpPlatformInterface::GetKernelParam(VpKernelID kernlId, RENDERHAL_KERNEL_PARAM &param)
@@ -639,6 +645,14 @@ MOS_STATUS VpPlatformInterface::GetInputFrameWidthHeightAlignUnit(
     return eStatus;
 }
 
+void VpPlatformInterface::SetForceVeboxInputHeight8AlignedFlag(bool enable)
+{
+    if (m_veboxItf)
+    {
+        m_veboxItf->SetForceInputHeight8AlignedFlag(enable);
+    }   
+}
+
 MOS_STATUS VpPlatformInterface::GetVeboxHeapInfo(
     PVP_MHWINTERFACE          pvpMhwInterface,
     const MHW_VEBOX_HEAP    **ppVeboxHeap)
@@ -672,7 +686,7 @@ bool VpPlatformInterface::IsVeboxScalabilityWith4KNotSupported(
 void VpPlatformInterface::DisableRender()
 {
     // media sfc interface should come to here.
-    VP_PUBLIC_NORMALMESSAGE("Disable Render.");
+    VP_PUBLIC_NORMALMESSAGE("Disable Render for media sfc interface path.");
     m_isRenderDisabled = true;
 }
 
@@ -684,6 +698,14 @@ MOS_STATUS VpRenderKernel::SetKernelExeEnv(KRN_EXECUTE_ENV &exeEnv)
     return MOS_STATUS_SUCCESS;
 }
 
+//for L0 use only
+MOS_STATUS VpRenderKernel::SetKernelPerThreadArgInfo(KRN_PER_THREAD_ARG_INFO &perThreadArgInfo)
+{
+    VP_FUNC_CALL();
+    m_kernelPerThreadArgInfo = perThreadArgInfo;
+    return MOS_STATUS_SUCCESS;
+}
+
 //for L0 use only
 MOS_STATUS VpRenderKernel::AddKernelBti(KRN_BTI &bti)
 {
@@ -703,26 +725,37 @@ MOS_STATUS VpRenderKernel::SetKernelCurbeSize(uint32_t size)
 
 //for L0 use only
 void VpPlatformInterface::InitVpDelayedNativeAdvKernel(
-    const uint32_t  *kernelBin,
-    uint32_t         kernelBinSize,
-    KRN_ARG         *kernelArgs,
-    uint32_t         kernelArgSize,
-    uint32_t         kernelCurbeSize,
-    KRN_EXECUTE_ENV &kernelExeEnv,
-    KRN_BTI         *kernelBtis,
-    uint32_t         kernelBtiSize,
-    std::string      kernelName)
+    const uint32_t         *kernelBin,
+    uint32_t                kernelBinSize,
+    KRN_ARG                *kernelArgs,
+    uint32_t                kernelArgSize,
+    uint32_t                kernelCurbeSize,
+    KRN_EXECUTE_ENV        &kernelExeEnv,
+    KRN_BTI                *kernelBtis,
+    uint32_t                kernelBtiSize,
+    std::string             kernelName,
+    KRN_PER_THREAD_ARG_INFO perThreadArgInfo)
 {
     VP_FUNC_CALL();
 
     VpRenderKernel vpKernel;
 
+    bool localIdGeneratedByRuntime = (kernelExeEnv.uiSlmSize > 0 && kernelExeEnv.uSimdSize == 1);
+
     vpKernel.SetKernelBinPointer((void *)kernelBin);
     vpKernel.SetKernelName(kernelName);
-    vpKernel.SetKernelBinOffset(0x0);
-    vpKernel.SetKernelBinSize(kernelBinSize);
+    if (localIdGeneratedByRuntime)
+    {
+        vpKernel.SetKernelBinSize(kernelBinSize);
+    }
+    else
+    {
+        vpKernel.SetKernelBinOffset(kernelExeEnv.uOffsetToSkipPerThreadDataLoad);
+        vpKernel.SetKernelBinSize(kernelBinSize - kernelExeEnv.uOffsetToSkipPerThreadDataLoad);
+    }
     vpKernel.SetKernelExeEnv(kernelExeEnv);
     vpKernel.SetKernelCurbeSize(kernelCurbeSize);
+    vpKernel.SetKernelPerThreadArgInfo(perThreadArgInfo);
 
     for (uint32_t i = 0; i < kernelArgSize; ++i)
     {
@@ -734,5 +767,5 @@ void VpPlatformInterface::InitVpDelayedNativeAdvKernel(
         vpKernel.AddKernelBti(kernelBtis[i]);
     }
 
-    m_kernelPool.insert(std::make_pair(vpKernel.GetKernelName(), vpKernel));
+    m_kernelPool.emplace(vpKernel.GetKernelName(), vpKernel);
 }
\ No newline at end of file
