@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022, Intel Corporation
+* Copyright (c) 2022-2023, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -72,15 +72,6 @@ VAStatus DdiDecodeVp9::ParseSliceParams(
         segParams->SegData[i].ChromaDCQuantScale = slcParam->seg_param[i].chroma_dc_quant_scale;
     }
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_PICPARAM))
-    {
-        DECODE_EVENTDATA_SEGPARAM_VP9 eventDataSegParam;
-        DecodeEventDataVP9SegParamInit(&eventDataSegParam, picParam, segParams->SegData);
-        MOS_TraceEvent(EVENT_DECODE_BUFFER_SEGPARAM_VP9, EVENT_TYPE_INFO, &eventDataSegParam, sizeof(eventDataSegParam), NULL, 0);
-    }
-#endif
-
     return VA_STATUS_SUCCESS;
 }
 
@@ -203,13 +194,6 @@ VAStatus DdiDecodeVp9::ParsePicParams(
     eventData.ChromaFormat                    = (subSamplingSum == 2) ? 1 : (subSamplingSum == 1 ? 2 : 3);  // 1-4:2:0; 2-4:2:2; 3-4:4:4
     eventData.EnabledSegment                  = picVp9Params->PicFlags.fields.segmentation_enabled;
     MOS_TraceEvent(EVENT_DECODE_INFO_PICTUREVA, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-
-    if (MOS_TraceKeyEnabled(TR_KEY_DECODE_PICPARAM))
-    {
-        DECODE_EVENTDATA_PICPARAM_VP9 eventDataPicParam;
-        DecodeEventDataVP9PicParamInit(&eventDataPicParam, picVp9Params);
-        MOS_TraceEvent(EVENT_DECODE_BUFFER_PICPARAM_VP9, EVENT_TYPE_INFO, &eventDataPicParam, sizeof(eventDataPicParam), NULL, 0);
-    }
 #endif
 
     return VA_STATUS_SUCCESS;
@@ -297,32 +281,6 @@ VAStatus DdiDecodeVp9::RenderPicture(
             m_decodeCtx->DecodeParams.m_dataSize += dataSize;
             slcFlag = true;
 
-#if MOS_EVENT_TRACE_DUMP_SUPPORTED
-            uint8_t *pDataBuf = (uint8_t *)MediaLibvaUtilNext::LockBuffer(m_decodeCtx->BufMgr.pBitStreamBuffObject[index], MOS_LOCKFLAG_READONLY);
-            DDI_CODEC_CHK_NULL(pDataBuf, "nullptr bitstream", VA_STATUS_ERROR_INVALID_BUFFER);
-
-            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM_INFO))
-            {
-                DECODE_EVENTDATA_BITSTREAM eventData;
-                for (int i = 0; i < 32; i++)
-                {
-                    eventData.Data[i] = pDataBuf[i];
-                }
-                MOS_TraceEvent(EVENT_DECODE_INFO_BITSTREAM, EVENT_TYPE_INFO, &eventData, sizeof(eventData), NULL, 0);
-            }
-
-            if (MOS_TraceKeyEnabled(TR_KEY_DECODE_BITSTREAM))
-            {
-                MOS_TraceDataDump(
-                "Decode_Bitstream",
-                0,
-                pDataBuf,
-                m_decodeCtx->DecodeParams.m_dataSize);
-            }
-                
-            MediaLibvaUtilNext::UnlockBuffer(m_decodeCtx->BufMgr.pBitStreamBuffObject[index]);
-#endif
-
             break;
         }
         case VASliceParameterBufferType:
@@ -738,53 +696,4 @@ void DdiDecodeVp9::ContextInit(
     return;
 }
 
-VAStatus DdiDecodeVp9::CheckDecodeResolution(
-    int32_t   codecMode,
-    VAProfile profile,
-    uint32_t  width,
-    uint32_t  height)
-{
-    DDI_CODEC_FUNC_ENTER;
-
-    uint32_t maxWidth = 0, maxHeight = 0;
-    switch (codecMode)
-    {
-    case CODECHAL_DECODE_MODE_VP9VLD:
-        maxWidth  = m_decVp9Max16kWidth;
-        maxHeight = m_decVp9Max16kHeight;
-        break;
-    default:
-        maxWidth  = m_decDefaultMaxWidth;
-        maxHeight = m_decDefaultMaxHeight;
-        break;
-    }
-
-    if (width > maxWidth || height > maxHeight)
-    {
-        return VA_STATUS_ERROR_RESOLUTION_NOT_SUPPORTED;
-    }
-    else
-    {
-        return VA_STATUS_SUCCESS;
-    }
-}
-
-CODECHAL_MODE DdiDecodeVp9::GetDecodeCodecMode(VAProfile profile)
-{
-    DDI_CODEC_FUNC_ENTER;
-
-    int8_t vaProfile = (int8_t)profile;
-    switch (vaProfile)
-    {
-    case VAProfileVP9Profile0:
-    case VAProfileVP9Profile1:
-    case VAProfileVP9Profile2:
-    case VAProfileVP9Profile3:
-        return CODECHAL_DECODE_MODE_VP9VLD;
-    default:
-        DDI_CODEC_ASSERTMESSAGE("Invalid Decode Mode");
-        return CODECHAL_UNSUPPORTED_MODE;
-    }
-}
-
 } // namespace decode
