@@ -188,16 +188,16 @@ VAStatus DdiEncodeFunctions::CreateContext (
         return vaStatus;
     }
 
+    if (configItem->entrypoint == VAEntrypointEncSlice)
+    {
+        encCtx->bVdencActive = true;
+    }
+
     encCtx->vaEntrypoint  = configItem->entrypoint;
     encCtx->vaProfile     = configItem->profile;
     encCtx->uiRCMethod    = configItem->componentData.data.rcMode;
     encCtx->wModeType     = ddiEncode->GetEncodeCodecMode(configItem->profile, configItem->entrypoint);
-    encCtx->codecFunction = ddiEncode->GetEncodeCodecFunction(configItem->profile, configItem->entrypoint);
-
-    if (configItem->entrypoint == VAEntrypointEncSliceLP)
-    {
-        encCtx->bVdencActive = true;
-    }
+    encCtx->codecFunction = ddiEncode->GetEncodeCodecFunction(configItem->profile, configItem->entrypoint, encCtx->bVdencActive);
 
     CODECHAL_STANDARD_INFO standardInfo;
     MOS_ZeroMemory(&standardInfo, sizeof(CODECHAL_STANDARD_INFO));
@@ -247,7 +247,6 @@ VAStatus DdiEncodeFunctions::CreateContext (
 
     MOS_STATUS eStatus = pCodecHal->Allocate(encCtx->m_encode->m_codechalSettings);
 
-#ifdef _MMC_SUPPORTED
     PMOS_INTERFACE osInterface = pCodecHal->GetOsInterface();
     if (osInterface != nullptr &&
         !osInterface->apoMosEnabled &&
@@ -257,7 +256,6 @@ VAStatus DdiEncodeFunctions::CreateContext (
         mediaCtx->pMediaMemDecompState =
             static_cast<MediaMemDecompState *>(MmdDevice::CreateFactory(&mosCtx));
     }
-#endif
 
     if (eStatus != MOS_STATUS_SUCCESS)
     {
